@@ -225,7 +225,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup laqr5
+*> \ingroup complexOTHERauxiliary
 *
 *> \par Contributors:
 *  ==================
@@ -251,8 +251,7 @@
 *>       ACM Trans. Math. Softw. 40, 2, Article 12 (February 2014).
 *>
 *  =====================================================================
-      SUBROUTINE CLAQR5( WANTT, WANTZ, KACC22, N, KTOP, KBOT, NSHFTS,
-     $                   S,
+      SUBROUTINE CLAQR5( WANTT, WANTZ, KACC22, N, KTOP, KBOT, NSHFTS, S,
      $                   H, LDH, ILOZ, IHIZ, Z, LDZ, V, LDV, U, LDU, NV,
      $                   WV, LDWV, NH, WH, LDWH )
       IMPLICIT NONE
@@ -280,7 +279,7 @@
       PARAMETER          ( RZERO = 0.0e0, RONE = 1.0e0 )
 *     ..
 *     .. Local Scalars ..
-      COMPLEX            ALPHA, BETA, CDUM, REFSUM, T1, T2, T3
+      COMPLEX            ALPHA, BETA, CDUM, REFSUM
       REAL               H11, H12, H21, H22, SAFMAX, SAFMIN, SCL,
      $                   SMLNUM, TST1, TST2, ULP
       INTEGER            I2, I4, INCOL, J, JBOT, JCOL, JLEN,
@@ -301,8 +300,8 @@
       COMPLEX            VT( 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CGEMM, CLACPY, CLAQR1, CLARFG, CLASET,
-     $                   CTRMM
+      EXTERNAL           CGEMM, CLACPY, CLAQR1, CLARFG, CLASET, CTRMM,
+     $                   SLABAD
 *     ..
 *     .. Statement Functions ..
       REAL               CABS1
@@ -332,6 +331,7 @@
 *
       SAFMIN = SLAMCH( 'SAFE MINIMUM' )
       SAFMAX = RONE / SAFMIN
+      CALL SLABAD( SAFMIN, SAFMAX )
       ULP = SLAMCH( 'PRECISION' )
       SMLNUM = SAFMIN*( REAL( N ) / ULP )
 *
@@ -424,12 +424,12 @@
 *              ==== Perform update from right within 
 *              .    computational window. ====
 *
-               T1 = V( 1, M22 )
-               T2 = T1*CONJG( V( 2, M22 ) )
                DO 30 J = JTOP, MIN( KBOT, K+3 )
-                  REFSUM = H( J, K+1 ) + V( 2, M22 )*H( J, K+2 )
-                  H( J, K+1 ) = H( J, K+1 ) - REFSUM*T1
-                  H( J, K+2 ) = H( J, K+2 ) - REFSUM*T2
+                  REFSUM = V( 1, M22 )*( H( J, K+1 )+V( 2, M22 )*
+     $                     H( J, K+2 ) )
+                  H( J, K+1 ) = H( J, K+1 ) - REFSUM
+                  H( J, K+2 ) = H( J, K+2 ) -
+     $                          REFSUM*CONJG( V( 2, M22 ) )
    30          CONTINUE
 *
 *              ==== Perform update from left within 
@@ -442,13 +442,12 @@
                ELSE
                   JBOT = KBOT
                END IF
-               T1 = CONJG( V( 1, M22 ) )
-               T2 = T1*V( 2, M22 )
                DO 40 J = K+1, JBOT
-                  REFSUM = H( K+1, J ) +
-     $                     CONJG( V( 2, M22 ) )*H( K+2, J )
-                  H( K+1, J ) = H( K+1, J ) - REFSUM*T1
-                  H( K+2, J ) = H( K+2, J ) - REFSUM*T2
+                  REFSUM = CONJG( V( 1, M22 ) )*
+     $                     ( H( K+1, J )+CONJG( V( 2, M22 ) )*
+     $                     H( K+2, J ) )
+                  H( K+1, J ) = H( K+1, J ) - REFSUM
+                  H( K+2, J ) = H( K+2, J ) - REFSUM*V( 2, M22 )
    40          CONTINUE
 *
 *              ==== The following convergence test requires that
@@ -533,13 +532,11 @@
 *                 .    Mth bulge. Exploit fact that first two elements
 *                 .    of row are actually zero. ====
 *
-                  T1 = V( 1, M )
-                  T2 = T1*CONJG( V( 2, M ) )
-                  T3 = T1*CONJG( V( 3, M ) )
-                  REFSUM = V( 3, M )*H( K+3, K+2 )
-                  H( K+3, K   ) = -REFSUM*T1
-                  H( K+3, K+1 ) = -REFSUM*T2
-                  H( K+3, K+2 ) = H( K+3, K+2 ) - REFSUM*T3
+                  REFSUM = V( 1, M )*V( 3, M )*H( K+3, K+2 )
+                  H( K+3, K   ) = -REFSUM
+                  H( K+3, K+1 ) = -REFSUM*CONJG( V( 2, M ) )
+                  H( K+3, K+2 ) = H( K+3, K+2 ) -
+     $                            REFSUM*CONJG( V( 3, M ) )
 *
 *                 ==== Calculate reflection to move
 *                 .    Mth bulge one step. ====
@@ -574,13 +571,12 @@
      $                            S( 2*M ), VT )
                      ALPHA = VT( 1 )
                      CALL CLARFG( 3, ALPHA, VT( 2 ), 1, VT( 1 ) )
-                     T1 = CONJG( VT( 1 ) )
-                     T2 = T1*VT( 2 )
-                     T3 = T1*VT( 3 )
-                     REFSUM = H( K+1, K )+CONJG( VT( 2 ) )*H( K+2, K )
+                     REFSUM = CONJG( VT( 1 ) )*
+     $                        ( H( K+1, K )+CONJG( VT( 2 ) )*
+     $                        H( K+2, K ) )
 *
-                     IF( CABS1( H( K+2, K )-REFSUM*T2 )+
-     $                   CABS1( REFSUM*T3 ).GT.ULP*
+                     IF( CABS1( H( K+2, K )-REFSUM*VT( 2 ) )+
+     $                   CABS1( REFSUM*VT( 3 ) ).GT.ULP*
      $                   ( CABS1( H( K, K ) )+CABS1( H( K+1,
      $                   K+1 ) )+CABS1( H( K+2, K+2 ) ) ) ) THEN
 *
@@ -598,7 +594,7 @@
 *                       .    Replace the old reflector with
 *                       .    the new one. ====
 *
-                        H( K+1, K ) = H( K+1, K ) - REFSUM*T1
+                        H( K+1, K ) = H( K+1, K ) - REFSUM
                         H( K+2, K ) = ZERO
                         H( K+3, K ) = ZERO
                         V( 1, M ) = VT( 1 )
@@ -614,28 +610,25 @@
 *              .     deflation check. We still delay most of the
 *              .     updates from the left for efficiency. ====
 *
-               T1 = V( 1, M )
-               T2 = T1*CONJG( V( 2, M ) )
-               T3 = T1*CONJG( V( 3, M ) )
                DO 70 J = JTOP, MIN( KBOT, K+3 )
-                  REFSUM = H( J, K+1 ) + V( 2, M )*H( J, K+2 )
-     $                     + V( 3, M )*H( J, K+3 )
-                  H( J, K+1 ) = H( J, K+1 ) - REFSUM*T1
-                  H( J, K+2 ) = H( J, K+2 ) - REFSUM*T2
-                  H( J, K+3 ) = H( J, K+3 ) - REFSUM*T3
+                  REFSUM = V( 1, M )*( H( J, K+1 )+V( 2, M )*
+     $                     H( J, K+2 )+V( 3, M )*H( J, K+3 ) )
+                  H( J, K+1 ) = H( J, K+1 ) - REFSUM
+                  H( J, K+2 ) = H( J, K+2 ) -
+     $                          REFSUM*CONJG( V( 2, M ) )
+                  H( J, K+3 ) = H( J, K+3 ) -
+     $                          REFSUM*CONJG( V( 3, M ) )
    70          CONTINUE
 *
 *              ==== Perform update from left for subsequent
 *              .    column. ====
 *
-               T1 = CONJG( V( 1, M ) )
-               T2 = T1*V( 2, M )
-               T3 = T1*V( 3, M )
-               REFSUM = H( K+1, K+1 ) + CONJG( V( 2, M ) )*H( K+2, K+1 )
-     $                  + CONJG( V( 3, M ) )*H( K+3, K+1 )
-               H( K+1, K+1 ) = H( K+1, K+1 ) - REFSUM*T1
-               H( K+2, K+1 ) = H( K+2, K+1 ) - REFSUM*T2
-               H( K+3, K+1 ) = H( K+3, K+1 ) - REFSUM*T3
+               REFSUM =  CONJG( V( 1, M ) )*( H( K+1, K+1 )
+     $                  +CONJG( V( 2, M ) )*H( K+2, K+1 )
+     $                  +CONJG( V( 3, M ) )*H( K+3, K+1 ) )
+               H( K+1, K+1 ) = H( K+1, K+1 ) - REFSUM
+               H( K+2, K+1 ) = H( K+2, K+1 ) - REFSUM*V( 2, M )
+               H( K+3, K+1 ) = H( K+3, K+1 ) - REFSUM*V( 3, M )
 *
 *              ==== The following convergence test requires that
 *              .    the tradition small-compared-to-nearby-diagonals
@@ -695,15 +688,13 @@
 *
             DO 100 M = MBOT, MTOP, -1
                K = KRCOL + 2*( M-1 )
-               T1 = CONJG( V( 1, M ) )
-               T2 = T1*V( 2, M )
-               T3 = T1*V( 3, M )
                DO 90 J = MAX( KTOP, KRCOL + 2*M ), JBOT
-                  REFSUM = H( K+1, J ) + CONJG( V( 2, M ) )*
-     $                     H( K+2, J ) + CONJG( V( 3, M ) )*H( K+3, J )
-                  H( K+1, J ) = H( K+1, J ) - REFSUM*T1
-                  H( K+2, J ) = H( K+2, J ) - REFSUM*T2
-                  H( K+3, J ) = H( K+3, J ) - REFSUM*T3
+                  REFSUM = CONJG( V( 1, M ) )*
+     $                     ( H( K+1, J )+CONJG( V( 2, M ) )*
+     $                     H( K+2, J )+CONJG( V( 3, M ) )*H( K+3, J ) )
+                  H( K+1, J ) = H( K+1, J ) - REFSUM
+                  H( K+2, J ) = H( K+2, J ) - REFSUM*V( 2, M )
+                  H( K+3, J ) = H( K+3, J ) - REFSUM*V( 3, M )
    90          CONTINUE
   100       CONTINUE
 *
@@ -721,15 +712,14 @@
                   I2 = MAX( 1, KTOP-INCOL )
                   I2 = MAX( I2, KMS-(KRCOL-INCOL)+1 )
                   I4 = MIN( KDU, KRCOL + 2*( MBOT-1 ) - INCOL + 5 )
-                  T1 = V( 1, M )
-                  T2 = T1*CONJG( V( 2, M ) )
-                  T3 = T1*CONJG( V( 3, M ) )
                   DO 110 J = I2, I4
-                     REFSUM = U( J, KMS+1 ) + V( 2, M )*U( J, KMS+2 )
-     $                        + V( 3, M )*U( J, KMS+3 )
-                     U( J, KMS+1 ) = U( J, KMS+1 ) - REFSUM*T1
-                     U( J, KMS+2 ) = U( J, KMS+2 ) - REFSUM*T2
-                     U( J, KMS+3 ) = U( J, KMS+3 ) - REFSUM*T3
+                     REFSUM = V( 1, M )*( U( J, KMS+1 )+V( 2, M )*
+     $                        U( J, KMS+2 )+V( 3, M )*U( J, KMS+3 ) )
+                     U( J, KMS+1 ) = U( J, KMS+1 ) - REFSUM
+                     U( J, KMS+2 ) = U( J, KMS+2 ) -
+     $                               REFSUM*CONJG( V( 2, M ) )
+                     U( J, KMS+3 ) = U( J, KMS+3 ) -
+     $                               REFSUM*CONJG( V( 3, M ) )
   110             CONTINUE
   120          CONTINUE
             ELSE IF( WANTZ ) THEN
@@ -740,15 +730,14 @@
 *
                DO 140 M = MBOT, MTOP, -1
                   K = KRCOL + 2*( M-1 )
-                  T1 = V( 1, M )
-                  T2 = T1*CONJG( V( 2, M ) )
-                  T3 = T1*CONJG( V( 3, M ) )
                   DO 130 J = ILOZ, IHIZ
-                     REFSUM = Z( J, K+1 ) + V( 2, M )*Z( J, K+2 )
-     $                        + V( 3, M )*Z( J, K+3 )
-                     Z( J, K+1 ) = Z( J, K+1 ) - REFSUM*T1
-                     Z( J, K+2 ) = Z( J, K+2 ) - REFSUM*T2
-                     Z( J, K+3 ) = Z( J, K+3 ) - REFSUM*T3
+                     REFSUM = V( 1, M )*( Z( J, K+1 )+V( 2, M )*
+     $                        Z( J, K+2 )+V( 3, M )*Z( J, K+3 ) )
+                     Z( J, K+1 ) = Z( J, K+1 ) - REFSUM
+                     Z( J, K+2 ) = Z( J, K+2 ) -
+     $                             REFSUM*CONJG( V( 2, M ) )
+                     Z( J, K+3 ) = Z( J, K+3 ) -
+     $                             REFSUM*CONJG( V( 3, M ) )
   130             CONTINUE
   140          CONTINUE
             END IF
