@@ -222,7 +222,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup trevc3
+*> \ingroup complex16OTHERcomputational
 *
 *> \par Further Details:
 *  =====================
@@ -239,8 +239,7 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      SUBROUTINE ZTREVC3( SIDE, HOWMNY, SELECT, N, T, LDT, VL, LDVL,
-     $                    VR,
+      SUBROUTINE ZTREVC3( SIDE, HOWMNY, SELECT, N, T, LDT, VL, LDVL, VR,
      $                    LDVR, MM, M, WORK, LWORK, RWORK, LRWORK, INFO)
       IMPLICIT NONE
 *
@@ -280,13 +279,11 @@
       LOGICAL            LSAME
       INTEGER            ILAENV, IZAMAX
       DOUBLE PRECISION   DLAMCH, DZASUM
-      EXTERNAL           LSAME, ILAENV, IZAMAX, DLAMCH,
-     $                   DZASUM
+      EXTERNAL           LSAME, ILAENV, IZAMAX, DLAMCH, DZASUM
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           XERBLA, ZCOPY, ZDSCAL, ZGEMV,
-     $                   ZLATRS,
-     $                   ZGEMM, ZLASET, ZLACPY
+      EXTERNAL           XERBLA, ZCOPY, ZDSCAL, ZGEMV, ZLATRS,
+     $                   ZGEMM, DLABAD, ZLASET, ZLACPY
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, DCMPLX, CONJG, DIMAG, MAX
@@ -324,9 +321,9 @@
 *
       INFO = 0
       NB = ILAENV( 1, 'ZTREVC', SIDE // HOWMNY, N, -1, -1, -1 )
-      MAXWRK = MAX( 1, N + 2*N*NB )
+      MAXWRK = N + 2*N*NB
       WORK(1) = MAXWRK
-      RWORK(1) = MAX( 1, N )
+      RWORK(1) = N
       LQUERY = ( LWORK.EQ.-1 .OR. LRWORK.EQ.-1 )
       IF( .NOT.RIGHTV .AND. .NOT.LEFTV ) THEN
          INFO = -1
@@ -374,6 +371,7 @@
 *
       UNFL = DLAMCH( 'Safe minimum' )
       OVFL = ONE / UNFL
+      CALL DLABAD( UNFL, OVFL )
       ULP = DLAMCH( 'Precision' )
       SMLNUM = UNFL*( N / ULP )
 *
@@ -545,8 +543,7 @@
   100       CONTINUE
 *
             IF( KI.LT.N ) THEN
-               CALL ZLATRS( 'Upper', 'Conjugate transpose',
-     $                      'Non-unit',
+               CALL ZLATRS( 'Upper', 'Conjugate transpose', 'Non-unit',
      $                      'Y', N-KI, T( KI+1, KI+1 ), LDT,
      $                      WORK( KI+1 + IV*N ), SCALE, RWORK, INFO )
                WORK( KI + IV*N ) = SCALE
@@ -557,8 +554,7 @@
             IF( .NOT.OVER ) THEN
 *              ------------------------------
 *              no back-transform: copy x to VL and normalize.
-               CALL ZCOPY( N-KI+1, WORK( KI + IV*N ), 1, VL(KI,IS),
-     $                     1 )
+               CALL ZCOPY( N-KI+1, WORK( KI + IV*N ), 1, VL(KI,IS), 1 )
 *
                II = IZAMAX( N-KI+1, VL( KI, IS ), 1 ) + KI - 1
                REMAX = ONE / CABS1( VL( II, IS ) )
@@ -572,8 +568,7 @@
 *              ------------------------------
 *              version 1: back-transform each vector with GEMV, Q*x.
                IF( KI.LT.N )
-     $            CALL ZGEMV( 'N', N, N-KI, CONE, VL( 1, KI+1 ),
-     $                        LDVL,
+     $            CALL ZGEMV( 'N', N, N-KI, CONE, VL( 1, KI+1 ), LDVL,
      $                        WORK( KI+1 + IV*N ), 1, DCMPLX( SCALE ),
      $                        VL( 1, KI ), 1 )
 *
