@@ -301,9 +301,8 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      SUBROUTINE DGEGV( JOBVL, JOBVR, N, A, LDA, B, LDB, ALPHAR,
-     $                  ALPHAI, BETA, VL, LDVL, VR, LDVR, WORK, LWORK,
-     $                  INFO )
+      SUBROUTINE DGEGV( JOBVL, JOBVR, N, A, LDA, B, LDB, ALPHAR, ALPHAI,
+     $                  BETA, VL, LDVL, VR, LDVR, WORK, LWORK, INFO )
 *
 *  -- LAPACK driver routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
