@@ -259,8 +259,7 @@
       EXTERNAL           ISAMAX, LSAME, SDOT, SNRM2
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SAXPY, SCOPY, SLASCL, SLASSQ, SROTM,
-     $                   SSWAP,
+      EXTERNAL           SAXPY, SCOPY, SLASCL, SLASSQ, SROTM, SSWAP,
      $                   XERBLA
 *     ..
 *     .. Executable Statements ..
@@ -425,15 +424,12 @@
                            IF( AAQQ.GE.ONE ) THEN
                               ROTOK = ( SMALL*AAPP ).LE.AAQQ
                               IF( AAPP.LT.( BIG / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
-     $                                    A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, p ), 1, WORK,
-     $                                       1 )
-                                 CALL SLASCL( 'G', 0, 0, AAPP,
-     $                                        D( p ),
+                                 CALL SCOPY( M, A( 1, p ), 1, WORK, 1 )
+                                 CALL SLASCL( 'G', 0, 0, AAPP, D( p ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, q ),
      $                                  1 )*D( q ) / AAQQ
@@ -441,15 +437,12 @@
                            ELSE
                               ROTOK = AAPP.LE.( AAQQ / SMALL )
                               IF( AAPP.GT.( SMALL / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
-     $                                    A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, q ), 1, WORK,
-     $                                       1 )
-                                 CALL SLASCL( 'G', 0, 0, AAQQ,
-     $                                        D( q ),
+                                 CALL SCOPY( M, A( 1, q ), 1, WORK, 1 )
+                                 CALL SLASCL( 'G', 0, 0, AAQQ, D( q ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, p ),
      $                                  1 )*D( p ) / AAPP
@@ -518,8 +511,7 @@
                                           FASTR( 4 ) = -T*AQOAP
                                           D( p ) = D( p )*CS
                                           D( q ) = D( q )*CS
-                                          CALL SROTM( M, A( 1, p ),
-     $                                                1,
+                                          CALL SROTM( M, A( 1, p ), 1,
      $                                                A( 1, q ), 1,
      $                                                FASTR )
                                           IF( RSVEC )CALL SROTM( MVL,
@@ -535,8 +527,7 @@
                                           D( p ) = D( p )*CS
                                           D( q ) = D( q ) / CS
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL,
-     $                                                   -T*AQOAP,
+                                             CALL SAXPY( MVL, -T*AQOAP,
      $                                                   V( 1, q ), 1,
      $                                                   V( 1, p ), 1 )
                                              CALL SAXPY( MVL,
@@ -550,15 +541,13 @@
                                           CALL SAXPY( M, T*APOAQ,
      $                                                A( 1, p ), 1,
      $                                                A( 1, q ), 1 )
-                                          CALL SAXPY( M,
-     $                                                -CS*SN*AQOAP,
+                                          CALL SAXPY( M, -CS*SN*AQOAP,
      $                                                A( 1, q ), 1,
      $                                                A( 1, p ), 1 )
                                           D( p ) = D( p ) / CS
                                           D( q ) = D( q )*CS
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL,
-     $                                                   T*APOAQ,
+                                             CALL SAXPY( MVL, T*APOAQ,
      $                                                   V( 1, p ), 1,
      $                                                   V( 1, q ), 1 )
                                              CALL SAXPY( MVL,
@@ -571,8 +560,7 @@
                                              CALL SAXPY( M, -T*AQOAP,
      $                                                   A( 1, q ), 1,
      $                                                   A( 1, p ), 1 )
-                                             CALL SAXPY( M,
-     $                                                   CS*SN*APOAQ,
+                                             CALL SAXPY( M, CS*SN*APOAQ,
      $                                                   A( 1, p ), 1,
      $                                                   A( 1, q ), 1 )
                                              D( p ) = D( p )*CS
@@ -613,19 +601,15 @@
 *
                               ELSE
 *              .. have to use modified Gram-Schmidt like transformation
-                                 CALL SCOPY( M, A( 1, p ), 1, WORK,
-     $                                       1 )
-                                 CALL SLASCL( 'G', 0, 0, AAPP, ONE,
-     $                                        M,
+                                 CALL SCOPY( M, A( 1, p ), 1, WORK, 1 )
+                                 CALL SLASCL( 'G', 0, 0, AAPP, ONE, M,
      $                                        1, WORK, LDA, IERR )
-                                 CALL SLASCL( 'G', 0, 0, AAQQ, ONE,
-     $                                        M,
+                                 CALL SLASCL( 'G', 0, 0, AAQQ, ONE, M,
      $                                        1, A( 1, q ), LDA, IERR )
                                  TEMP1 = -AAPQ*D( p ) / D( q )
                                  CALL SAXPY( M, TEMP1, WORK, 1,
      $                                       A( 1, q ), 1 )
-                                 CALL SLASCL( 'G', 0, 0, ONE, AAQQ,
-     $                                        M,
+                                 CALL SLASCL( 'G', 0, 0, ONE, AAQQ, M,
      $                                        1, A( 1, q ), LDA, IERR )
                                  SVA( q ) = AAQQ*SQRT( MAX( ZERO,
      $                                      ONE-AAPQ*AAPQ ) )
@@ -639,8 +623,7 @@
      $                            THEN
                                  IF( ( AAQQ.LT.ROOTBIG ) .AND.
      $                               ( AAQQ.GT.ROOTSFMIN ) ) THEN
-                                    SVA( q ) = SNRM2( M, A( 1, q ),
-     $                                   1 )*
+                                    SVA( q ) = SNRM2( M, A( 1, q ), 1 )*
      $                                         D( q )
                                  ELSE
                                     T = ZERO
@@ -741,15 +724,12 @@
                                  ROTOK = ( SMALL*AAQQ ).LE.AAPP
                               END IF
                               IF( AAPP.LT.( BIG / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
-     $                                    A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, p ), 1, WORK,
-     $                                       1 )
-                                 CALL SLASCL( 'G', 0, 0, AAPP,
-     $                                        D( p ),
+                                 CALL SCOPY( M, A( 1, p ), 1, WORK, 1 )
+                                 CALL SLASCL( 'G', 0, 0, AAPP, D( p ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, q ),
      $                                  1 )*D( q ) / AAQQ
@@ -761,15 +741,12 @@
                                  ROTOK = AAQQ.LE.( AAPP / SMALL )
                               END IF
                               IF( AAPP.GT.( SMALL / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
-     $                                    A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, q ), 1, WORK,
-     $                                       1 )
-                                 CALL SLASCL( 'G', 0, 0, AAQQ,
-     $                                        D( q ),
+                                 CALL SCOPY( M, A( 1, q ), 1, WORK, 1 )
+                                 CALL SLASCL( 'G', 0, 0, AAQQ, D( q ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, p ),
      $                                  1 )*D( p ) / AAPP
@@ -833,8 +810,7 @@
                                           FASTR( 4 ) = -T*AQOAP
                                           D( p ) = D( p )*CS
                                           D( q ) = D( q )*CS
-                                          CALL SROTM( M, A( 1, p ),
-     $                                                1,
+                                          CALL SROTM( M, A( 1, p ), 1,
      $                                                A( 1, q ), 1,
      $                                                FASTR )
                                           IF( RSVEC )CALL SROTM( MVL,
@@ -848,8 +824,7 @@
      $                                                A( 1, p ), 1,
      $                                                A( 1, q ), 1 )
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL,
-     $                                                   -T*AQOAP,
+                                             CALL SAXPY( MVL, -T*AQOAP,
      $                                                   V( 1, q ), 1,
      $                                                   V( 1, p ), 1 )
                                              CALL SAXPY( MVL,
@@ -865,13 +840,11 @@
                                           CALL SAXPY( M, T*APOAQ,
      $                                                A( 1, p ), 1,
      $                                                A( 1, q ), 1 )
-                                          CALL SAXPY( M,
-     $                                                -CS*SN*AQOAP,
+                                          CALL SAXPY( M, -CS*SN*AQOAP,
      $                                                A( 1, q ), 1,
      $                                                A( 1, p ), 1 )
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL,
-     $                                                   T*APOAQ,
+                                             CALL SAXPY( MVL, T*APOAQ,
      $                                                   V( 1, p ), 1,
      $                                                   V( 1, q ), 1 )
                                              CALL SAXPY( MVL,
@@ -886,8 +859,7 @@
                                              CALL SAXPY( M, -T*AQOAP,
      $                                                   A( 1, q ), 1,
      $                                                   A( 1, p ), 1 )
-                                             CALL SAXPY( M,
-     $                                                   CS*SN*APOAQ,
+                                             CALL SAXPY( M, CS*SN*APOAQ,
      $                                                   A( 1, p ), 1,
      $                                                   A( 1, q ), 1 )
                                              D( p ) = D( p )*CS
@@ -928,42 +900,34 @@
 *
                               ELSE
                                  IF( AAPP.GT.AAQQ ) THEN
-                                    CALL SCOPY( M, A( 1, p ), 1,
-     $                                          WORK,
+                                    CALL SCOPY( M, A( 1, p ), 1, WORK,
      $                                          1 )
-                                    CALL SLASCL( 'G', 0, 0, AAPP,
-     $                                           ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAPP, ONE,
      $                                           M, 1, WORK, LDA, IERR )
-                                    CALL SLASCL( 'G', 0, 0, AAQQ,
-     $                                           ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAQQ, ONE,
      $                                           M, 1, A( 1, q ), LDA,
      $                                           IERR )
                                     TEMP1 = -AAPQ*D( p ) / D( q )
                                     CALL SAXPY( M, TEMP1, WORK, 1,
      $                                          A( 1, q ), 1 )
-                                    CALL SLASCL( 'G', 0, 0, ONE,
-     $                                           AAQQ,
+                                    CALL SLASCL( 'G', 0, 0, ONE, AAQQ,
      $                                           M, 1, A( 1, q ), LDA,
      $                                           IERR )
                                     SVA( q ) = AAQQ*SQRT( MAX( ZERO,
      $                                         ONE-AAPQ*AAPQ ) )
                                     MXSINJ = MAX( MXSINJ, SFMIN )
                                  ELSE
-                                    CALL SCOPY( M, A( 1, q ), 1,
-     $                                          WORK,
+                                    CALL SCOPY( M, A( 1, q ), 1, WORK,
      $                                          1 )
-                                    CALL SLASCL( 'G', 0, 0, AAQQ,
-     $                                           ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAQQ, ONE,
      $                                           M, 1, WORK, LDA, IERR )
-                                    CALL SLASCL( 'G', 0, 0, AAPP,
-     $                                           ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAPP, ONE,
      $                                           M, 1, A( 1, p ), LDA,
      $                                           IERR )
                                     TEMP1 = -AAPQ*D( q ) / D( p )
                                     CALL SAXPY( M, TEMP1, WORK, 1,
      $                                          A( 1, p ), 1 )
-                                    CALL SLASCL( 'G', 0, 0, ONE,
-     $                                           AAPP,
+                                    CALL SLASCL( 'G', 0, 0, ONE, AAPP,
      $                                           M, 1, A( 1, p ), LDA,
      $                                           IERR )
                                     SVA( p ) = AAPP*SQRT( MAX( ZERO,
@@ -979,8 +943,7 @@
      $                            THEN
                                  IF( ( AAQQ.LT.ROOTBIG ) .AND.
      $                               ( AAQQ.GT.ROOTSFMIN ) ) THEN
-                                    SVA( q ) = SNRM2( M, A( 1, q ),
-     $                                   1 )*
+                                    SVA( q ) = SNRM2( M, A( 1, q ), 1 )*
      $                                         D( q )
                                  ELSE
                                     T = ZERO
