@@ -337,8 +337,7 @@
       EXTERNAL           SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SCOPY, SLAR1V, SLARRB, SLARRF,
-     $                   SLASET,
+      EXTERNAL           SCOPY, SLAR1V, SLARRB, SLARRF, SLASET,
      $                   SSCAL
 *     ..
 *     .. Intrinsic Functions ..
