@@ -53,12 +53,6 @@
 *>
 *> Note that the routine returns VT = V**H, not V.
 *>
-*> The divide and conquer algorithm makes very mild assumptions about
-*> floating point arithmetic. It will work on machines with a guard
-*> digit in add/subtract, or on those binary machines without guard
-*> digits which subtract like the Cray X-MP, Cray Y-MP, Cray C-90, or
-*> Cray-2. It could conceivably fail on hexadecimal or decimal machines
-*> without guard digits, but we know of none.
 *> \endverbatim
 *
 *  Arguments:
@@ -213,7 +207,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complexGEsing
+*> \ingroup gesdd
 *
 *> \par Contributors:
 *  ==================
@@ -274,14 +268,16 @@
       COMPLEX            CDUM( 1 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CGEBRD, CGELQF, CGEMM, CGEQRF, CLACP2, CLACPY,
+      EXTERNAL           CGEBRD, CGELQF, CGEMM, CGEQRF, CLACP2,
+     $                   CLACPY,
      $                   CLACRM, CLARCM, CLASCL, CLASET, CUNGBR, CUNGLQ,
      $                   CUNGQR, CUNMBR, SBDSDC, SLASCL, XERBLA
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME, SISNAN
-      REAL               SLAMCH, CLANGE
-      EXTERNAL           LSAME, SLAMCH, CLANGE, SISNAN
+      REAL               SLAMCH, CLANGE, SROUNDUP_LWORK
+      EXTERNAL           LSAME, SLAMCH, CLANGE, SISNAN, 
+     $                   SROUNDUP_LWORK
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          INT, MAX, MIN, SQRT
@@ -292,8 +288,8 @@
 *
       INFO   = 0
       MINMN  = MIN( M, N )
-      MNTHR1 = INT( MINMN*17.0E0 / 9.0E0 )
-      MNTHR2 = INT( MINMN*5.0E0 / 3.0E0 )
+      MNTHR1 = INT( REAL( MINMN )*17.0E0 / 9.0E0 )
+      MNTHR2 = INT( REAL( MINMN )*5.0E0 / 3.0E0 )
       WNTQA  = LSAME( JOBZ, 'A' )
       WNTQS  = LSAME( JOBZ, 'S' )
       WNTQAS = WNTQA .OR. WNTQS
@@ -348,7 +344,8 @@
      $                   CDUM(1), CDUM(1), -1, IERR )
             LWORK_CGEBRD_NN = INT( CDUM(1) )
 *
-            CALL CGEQRF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1, IERR )
+            CALL CGEQRF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1,
+     $                   IERR )
             LWORK_CGEQRF_MN = INT( CDUM(1) )
 *
             CALL CUNGBR( 'P', N, N, N, CDUM(1), N, CDUM(1), CDUM(1),
@@ -489,7 +486,8 @@
      $                   CDUM(1), CDUM(1), -1, IERR )
             LWORK_CGEBRD_MM = INT( CDUM(1) )
 *
-            CALL CGELQF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1, IERR )
+            CALL CGELQF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1,
+     $                   IERR )
             LWORK_CGELQF_MN = INT( CDUM(1) )
 *
             CALL CUNGBR( 'P', M, N, M, CDUM(1), M, CDUM(1), CDUM(1),
@@ -617,7 +615,7 @@
          MAXWRK = MAX( MAXWRK, MINWRK )
       END IF
       IF( INFO.EQ.0 ) THEN
-         WORK( 1 ) = MAXWRK
+         WORK( 1 ) = SROUNDUP_LWORK( MAXWRK )
          IF( LWORK.LT.MINWRK .AND. .NOT. LQUERY ) THEN
             INFO = -12
          END IF
@@ -679,7 +677,8 @@
 *              CWorkspace: prefer N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Zero out below R
@@ -696,7 +695,8 @@
 *              CWorkspace: prefer 2*N [tauq, taup] + 2*N*NB [work]
 *              RWorkspace: need   N [e]
 *
-               CALL CGEBRD( N, N, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL CGEBRD( N, N, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
                NRWORK = IE + N
@@ -736,13 +736,15 @@
 *              CWorkspace: prefer N*N [U] + N*N [R] + N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy R to WORK( IR ), zeroing out below it
 *
                CALL CLACPY( 'U', N, N, A, LDA, WORK( IR ), LDWRKR )
-               CALL CLASET( 'L', N-1, N-1, CZERO, CZERO, WORK( IR+1 ),
+               CALL CLASET( 'L', N-1, N-1, CZERO, CZERO,
+     $                      WORK( IR+1 ),
      $                      LDWRKR )
 *
 *              Generate Q in A
@@ -775,7 +777,8 @@
                IRU = IE + N
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -787,7 +790,8 @@
 *
                CALL CLACP2( 'F', N, N, RWORK( IRU ), N, WORK( IU ),
      $                      LDWRKU )
-               CALL CUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ), LDWRKR,
+               CALL CUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUQ ), WORK( IU ), LDWRKU,
      $                      WORK( NWORK ), LWORK-NWORK+1, IERR )
 *
@@ -798,7 +802,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACP2( 'F', N, N, RWORK( IRVT ), N, VT, LDVT )
-               CALL CUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ), LDWRKR,
+               CALL CUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -836,13 +841,15 @@
 *              CWorkspace: prefer N*N [R] + N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy R to WORK(IR), zeroing out below it
 *
                CALL CLACPY( 'U', N, N, A, LDA, WORK( IR ), LDWRKR )
-               CALL CLASET( 'L', N-1, N-1, CZERO, CZERO, WORK( IR+1 ),
+               CALL CLASET( 'L', N-1, N-1, CZERO, CZERO,
+     $                      WORK( IR+1 ),
      $                      LDWRKR )
 *
 *              Generate Q in A
@@ -875,7 +882,8 @@
                IRU = IE + N
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -886,7 +894,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACP2( 'F', N, N, RWORK( IRU ), N, U, LDU )
-               CALL CUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ), LDWRKR,
+               CALL CUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -897,7 +906,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACP2( 'F', N, N, RWORK( IRVT ), N, VT, LDVT )
-               CALL CUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ), LDWRKR,
+               CALL CUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -907,7 +917,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACPY( 'F', N, N, U, LDU, WORK( IR ), LDWRKR )
-               CALL CGEMM( 'N', 'N', M, N, N, CONE, A, LDA, WORK( IR ),
+               CALL CGEMM( 'N', 'N', M, N, N, CONE, A, LDA,
+     $                     WORK( IR ),
      $                     LDWRKR, CZERO, U, LDU )
 *
             ELSE IF( WNTQA ) THEN
@@ -929,7 +940,8 @@
 *              CWorkspace: prefer N*N [U] + N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
                CALL CLACPY( 'L', M, N, A, LDA, U, LDU )
 *
@@ -955,7 +967,8 @@
 *              CWorkspace: prefer N*N [U] + 2*N [tauq, taup] + 2*N*NB [work]
 *              RWorkspace: need   N [e]
 *
-               CALL CGEBRD( N, N, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL CGEBRD( N, N, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
                IRU = IE + N
@@ -968,7 +981,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + N*N [RU] + N*N [RVT] + BDSPAC
 *
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1000,7 +1014,8 @@
 *              CWorkspace: need   N*N [U]
 *              RWorkspace: need   0
 *
-               CALL CGEMM( 'N', 'N', M, N, N, CONE, U, LDU, WORK( IU ),
+               CALL CGEMM( 'N', 'N', M, N, N, CONE, U, LDU,
+     $                     WORK( IU ),
      $                     LDWRKU, CZERO, A, LDA )
 *
 *              Copy left singular vectors of A from A to U
@@ -1038,7 +1053,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + BDSPAC
 *
-               CALL SBDSDC( 'U', 'N', N, S, RWORK( IE ), DUM, 1,DUM,1,
+               CALL SBDSDC( 'U', 'N', N, S, RWORK( IE ), DUM, 1,DUM,
+     $                      1,
      $                      DUM, IDUM, RWORK( NRWORK ), IWORK, INFO )
             ELSE IF( WNTQO ) THEN
                IU = NWORK
@@ -1083,7 +1099,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + N*N [RU] + N*N [RVT] + BDSPAC
 *
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1106,7 +1123,8 @@
                NRWORK = IRVT
                DO 20 I = 1, M, LDWRKU
                   CHUNK = MIN( M-I+1, LDWRKU )
-                  CALL CLACRM( CHUNK, N, A( I, 1 ), LDA, RWORK( IRU ),
+                  CALL CLACRM( CHUNK, N, A( I, 1 ), LDA,
+     $                         RWORK( IRU ),
      $                         N, WORK( IU ), LDWRKU, RWORK( NRWORK ) )
                   CALL CLACPY( 'F', CHUNK, N, WORK( IU ), LDWRKU,
      $                         A( I, 1 ), LDA )
@@ -1142,7 +1160,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1194,7 +1213,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1274,7 +1294,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + N*N [RU] + N*N [RVT] + BDSPAC
 *
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1301,12 +1322,14 @@
 *
                   CALL CLASET( 'F', M, N, CZERO, CZERO, WORK( IU ),
      $                         LDWRKU )
-                  CALL CLACP2( 'F', N, N, RWORK( IRU ), N, WORK( IU ),
+                  CALL CLACP2( 'F', N, N, RWORK( IRU ), N,
+     $                         WORK( IU ),
      $                         LDWRKU )
                   CALL CUNMBR( 'Q', 'L', 'N', M, N, N, A, LDA,
      $                         WORK( ITAUQ ), WORK( IU ), LDWRKU,
      $                         WORK( NWORK ), LWORK-NWORK+1, IERR )
-                  CALL CLACPY( 'F', M, N, WORK( IU ), LDWRKU, A, LDA )
+                  CALL CLACPY( 'F', M, N, WORK( IU ), LDWRKU, A,
+     $                         LDA )
                ELSE
 *
 *                 Path 6o-slow
@@ -1348,7 +1371,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1386,7 +1410,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1444,7 +1469,8 @@
 *              CWorkspace: prefer M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Zero out above L
@@ -1461,7 +1487,8 @@
 *              CWorkspace: prefer 2*M [tauq, taup] + 2*M*NB [work]
 *              RWorkspace: need   M [e]
 *
-               CALL CGEBRD( M, M, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL CGEBRD( M, M, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
                NRWORK = IE + M
@@ -1506,7 +1533,8 @@
 *              CWorkspace: prefer M*M [VT] + M*M [L] + M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy L to WORK(IL), zeroing about above it
@@ -1545,7 +1573,8 @@
                IRU = IE + M
                IRVT = IRU + M*M
                NRWORK = IRVT + M*M
-               CALL SBDSDC( 'U', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1556,7 +1585,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACP2( 'F', M, M, RWORK( IRU ), M, U, LDU )
-               CALL CUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ), LDWRKL,
+               CALL CUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -1568,7 +1598,8 @@
 *
                CALL CLACP2( 'F', M, M, RWORK( IRVT ), M, WORK( IVT ),
      $                      LDWKVT )
-               CALL CUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ), LDWRKL,
+               CALL CUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUP ), WORK( IVT ), LDWKVT,
      $                      WORK( NWORK ), LWORK-NWORK+1, IERR )
 *
@@ -1580,7 +1611,8 @@
 *
                DO 40 I = 1, N, CHUNK
                   BLK = MIN( N-I+1, CHUNK )
-                  CALL CGEMM( 'N', 'N', M, BLK, M, CONE, WORK( IVT ), M,
+                  CALL CGEMM( 'N', 'N', M, BLK, M, CONE, WORK( IVT ),
+     $                        M,
      $                        A( 1, I ), LDA, CZERO, WORK( IL ),
      $                        LDWRKL )
                   CALL CLACPY( 'F', M, BLK, WORK( IL ), LDWRKL,
@@ -1606,7 +1638,8 @@
 *              CWorkspace: prefer M*M [L] + M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy L to WORK(IL), zeroing out above it
@@ -1645,7 +1678,8 @@
                IRU = IE + M
                IRVT = IRU + M*M
                NRWORK = IRVT + M*M
-               CALL SBDSDC( 'U', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1656,7 +1690,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACP2( 'F', M, M, RWORK( IRU ), M, U, LDU )
-               CALL CUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ), LDWRKL,
+               CALL CUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -1667,7 +1702,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACP2( 'F', M, M, RWORK( IRVT ), M, VT, LDVT )
-               CALL CUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ), LDWRKL,
+               CALL CUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -1677,7 +1713,8 @@
 *              RWorkspace: need   0
 *
                CALL CLACPY( 'F', M, M, VT, LDVT, WORK( IL ), LDWRKL )
-               CALL CGEMM( 'N', 'N', M, N, M, CONE, WORK( IL ), LDWRKL,
+               CALL CGEMM( 'N', 'N', M, N, M, CONE, WORK( IL ),
+     $                     LDWRKL,
      $                     A, LDA, CZERO, VT, LDVT )
 *
             ELSE IF( WNTQA ) THEN
@@ -1699,7 +1736,8 @@
 *              CWorkspace: prefer M*M [VT] + M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL CGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL CGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
                CALL CLACPY( 'U', M, N, A, LDA, VT, LDVT )
 *
@@ -1725,7 +1763,8 @@
 *              CWorkspace: prefer M*M [VT] + 2*M [tauq, taup] + 2*M*NB [work]
 *              RWorkspace: need   M [e]
 *
-               CALL CGEBRD( M, M, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL CGEBRD( M, M, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
 *
@@ -1738,7 +1777,8 @@
                IRU = IE + M
                IRVT = IRU + M*M
                NRWORK = IRVT + M*M
-               CALL SBDSDC( 'U', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'U', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1770,7 +1810,8 @@
 *              CWorkspace: need   M*M [VT]
 *              RWorkspace: need   0
 *
-               CALL CGEMM( 'N', 'N', M, N, M, CONE, WORK( IVT ), LDWKVT,
+               CALL CGEMM( 'N', 'N', M, N, M, CONE, WORK( IVT ),
+     $                     LDWKVT,
      $                     VT, LDVT, CZERO, A, LDA )
 *
 *              Copy right singular vectors of A from A to VT
@@ -1856,7 +1897,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   M [e] + M*M [RVT] + M*M [RU] + BDSPAC
 *
-               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1865,7 +1907,8 @@
 *              CWorkspace: need   2*M [tauq, taup] + M*M [VT]
 *              RWorkspace: need   M [e] + M*M [RVT] + M*M [RU] + 2*M*M [rwork]
 *
-               CALL CLACRM( M, M, U, LDU, RWORK( IRU ), M, WORK( IVT ),
+               CALL CLACRM( M, M, U, LDU, RWORK( IRU ), M,
+     $                      WORK( IVT ),
      $                      LDWKVT, RWORK( NRWORK ) )
                CALL CLACPY( 'F', M, M, WORK( IVT ), LDWKVT, U, LDU )
 *
@@ -1879,7 +1922,8 @@
                NRWORK = IRU
                DO 50 I = 1, N, CHUNK
                   BLK = MIN( N-I+1, CHUNK )
-                  CALL CLARCM( M, BLK, RWORK( IRVT ), M, A( 1, I ), LDA,
+                  CALL CLARCM( M, BLK, RWORK( IRVT ), M, A( 1, I ),
+     $                         LDA,
      $                         WORK( IVT ), LDWKVT, RWORK( NRWORK ) )
                   CALL CLACPY( 'F', M, BLK, WORK( IVT ), LDWKVT,
      $                         A( 1, I ), LDA )
@@ -1914,7 +1958,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1966,7 +2011,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2049,7 +2095,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2074,12 +2121,14 @@
 *                 CWorkspace: prefer 2*M [tauq, taup] + M*N [VT] + M*NB [work]
 *                 RWorkspace: need   M [e] + M*M [RVT]
 *
-                  CALL CLACP2( 'F', M, M, RWORK( IRVT ), M, WORK( IVT ),
+                  CALL CLACP2( 'F', M, M, RWORK( IRVT ), M,
+     $                         WORK( IVT ),
      $                         LDWKVT )
                   CALL CUNMBR( 'P', 'R', 'C', M, N, M, A, LDA,
      $                         WORK( ITAUP ), WORK( IVT ), LDWKVT,
      $                         WORK( NWORK ), LWORK-NWORK+1, IERR )
-                  CALL CLACPY( 'F', M, N, WORK( IVT ), LDWKVT, A, LDA )
+                  CALL CLACPY( 'F', M, N, WORK( IVT ), LDWKVT, A,
+     $                         LDA )
                ELSE
 *
 *                 Path 6to-slow
@@ -2101,7 +2150,8 @@
                   NRWORK = IRU
                   DO 60 I = 1, N, CHUNK
                      BLK = MIN( N-I+1, CHUNK )
-                     CALL CLARCM( M, BLK, RWORK( IRVT ), M, A( 1, I ),
+                     CALL CLARCM( M, BLK, RWORK( IRVT ), M, A( 1,
+     $                            I ),
      $                            LDA, WORK( IVT ), LDWKVT,
      $                            RWORK( NRWORK ) )
                      CALL CLACPY( 'F', M, BLK, WORK( IVT ), LDWKVT,
@@ -2120,7 +2170,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2159,7 +2210,8 @@
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
 *
-               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL SBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2213,7 +2265,7 @@
 *
 *     Return optimal workspace in WORK(1)
 *
-      WORK( 1 ) = MAXWRK
+      WORK( 1 ) = SROUNDUP_LWORK( MAXWRK )
 *
       RETURN
 *
