@@ -263,10 +263,12 @@
       LOGICAL            LSAME
       INTEGER            ISAMAX
       REAL               SDOT, SLAMCH, SNRM2
-      EXTERNAL           ISAMAX, LSAME, SAXPY, SDOT, SLAMCH, SNRM2
+      EXTERNAL           ISAMAX, LSAME, SAXPY, SDOT, SLAMCH,
+     $                   SNRM2
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SCOPY, SLASET, SSCAL, SSWAP, SSTEVX, XERBLA
+      EXTERNAL           SCOPY, SLASET, SSCAL, SSWAP, SSTEVX,
+     $                   XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, REAL, SIGN, SQRT
@@ -423,7 +425,8 @@
          IF( NS.EQ.0 ) THEN
             RETURN
          ELSE
-            IF( WANTZ ) CALL SLASET( 'F', N*2, NS, ZERO, ZERO, Z, LDZ )
+            IF( WANTZ ) CALL SLASET( 'F', N*2, NS, ZERO, ZERO, Z,
+     $          LDZ )
          END IF
       ELSE IF( INDSV ) THEN
 *
@@ -444,7 +447,7 @@
      $                VLTGK, VLTGK, ILTGK, ILTGK, ABSTOL, NS, S,
      $                Z, LDZ, WORK( ITEMP ), IWORK( IIWORK ),
      $                IWORK( IIFAIL ), INFO )
-         VLTGK = S( 1 ) - FUDGE*SMAX*ULP*N
+         VLTGK = S( 1 ) - FUDGE*SMAX*ULP*REAL( N )
          WORK( IDTGK:IDTGK+2*N-1 ) = ZERO
          CALL SCOPY( N, D, 1, WORK( IETGK ), 2 )
          CALL SCOPY( N-1, E, 1, WORK( IETGK+1 ), 2 )
@@ -452,7 +455,7 @@
      $                VUTGK, VUTGK, IUTGK, IUTGK, ABSTOL, NS, S,
      $                Z, LDZ, WORK( ITEMP ), IWORK( IIWORK ),
      $                IWORK( IIFAIL ), INFO )
-         VUTGK = S( 1 ) + FUDGE*SMAX*ULP*N
+         VUTGK = S( 1 ) + FUDGE*SMAX*ULP*REAL( N )
          VUTGK = MIN( VUTGK, ZERO )
 *
 *        If VLTGK=VUTGK, SSTEVX returns an error message,
@@ -460,7 +463,8 @@
 *
          IF( VLTGK.EQ.VUTGK ) VLTGK = VLTGK - TOL
 *
-         IF( WANTZ ) CALL SLASET( 'F', N*2, IU-IL+1, ZERO, ZERO, Z, LDZ)
+         IF( WANTZ ) CALL SLASET( 'F', N*2, IU-IL+1, ZERO, ZERO, Z,
+     $       LDZ)
       END IF
 *
 *     Initialize variables and pointers for S, Z, and WORK.
@@ -587,7 +591,8 @@
 *                 WORK( ITEMP: ): 2*5*NTGK
 *                 IWORK( 1: ): 2*6*NTGK
 *
-                  CALL SSTEVX( JOBZ, RNGVX, NTGK, WORK( IDTGK+ISPLT-1 ),
+                  CALL SSTEVX( JOBZ, RNGVX, NTGK,
+     $                         WORK( IDTGK+ISPLT-1 ),
      $                         WORK( IETGK+ISPLT-1 ), VLTGK, VUTGK,
      $                         ILTGK, IUTGK, ABSTOL, NSL, S( ISBEG ),
      $                         Z( IROWZ,ICOLZ ), LDZ, WORK( ITEMP ),
@@ -642,13 +647,15 @@
      $                      ABS( NRMU-ORTOL )*SQRT2.GT.ONE )
      $                      THEN
                            DO J = 0, I-1
-                              ZJTJI = -SDOT( NRU, Z( IROWU, ICOLZ+J ),
+                              ZJTJI = -SDOT( NRU, Z( IROWU,
+     $                                       ICOLZ+J ),
      $                                       2, Z( IROWU, ICOLZ+I ), 2 )
                               CALL SAXPY( NRU, ZJTJI,
      $                                    Z( IROWU, ICOLZ+J ), 2,
      $                                    Z( IROWU, ICOLZ+I ), 2 )
                            END DO
-                           NRMU = SNRM2( NRU, Z( IROWU, ICOLZ+I ), 2 )
+                           NRMU = SNRM2( NRU, Z( IROWU, ICOLZ+I ),
+     $                                   2 )
                            CALL SSCAL( NRU, ONE/NRMU,
      $                                 Z( IROWU,ICOLZ+I ), 2 )
                         END IF
@@ -665,13 +672,15 @@
      $                      ABS( NRMV-ORTOL )*SQRT2.GT.ONE )
      $                      THEN
                            DO J = 0, I-1
-                              ZJTJI = -SDOT( NRV, Z( IROWV, ICOLZ+J ),
+                              ZJTJI = -SDOT( NRV, Z( IROWV,
+     $                                       ICOLZ+J ),
      $                                       2, Z( IROWV, ICOLZ+I ), 2 )
                               CALL SAXPY( NRU, ZJTJI,
      $                                    Z( IROWV, ICOLZ+J ), 2,
      $                                    Z( IROWV, ICOLZ+I ), 2 )
                            END DO
-                           NRMV = SNRM2( NRV, Z( IROWV, ICOLZ+I ), 2 )
+                           NRMV = SNRM2( NRV, Z( IROWV, ICOLZ+I ),
+     $                                   2 )
                            CALL SSCAL( NRV, ONE/NRMV,
      $                                 Z( IROWV,ICOLZ+I ), 2 )
                         END IF
@@ -751,7 +760,8 @@
          IF( K.NE.NS+1-I ) THEN
             S( K ) = S( NS+1-I )
             S( NS+1-I ) = SMIN
-            IF( WANTZ ) CALL SSWAP( N*2, Z( 1,K ), 1, Z( 1,NS+1-I ), 1 )
+            IF( WANTZ ) CALL SSWAP( N*2, Z( 1,K ), 1, Z( 1,NS+1-I ),
+     $          1 )
          END IF
       END DO
 *
