@@ -133,15 +133,18 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup lantb
+*> \date December 2016
+*
+*> \ingroup complexOTHERauxiliary
 *
 *  =====================================================================
       REAL             FUNCTION CLANTB( NORM, UPLO, DIAG, N, K, AB,
      $                 LDAB, WORK )
 *
-*  -- LAPACK auxiliary routine --
+*  -- LAPACK auxiliary routine (version 3.7.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIAG, NORM, UPLO
@@ -187,16 +190,14 @@
                DO 20 J = 1, N
                   DO 10 I = MAX( K+2-J, 1 ), K
                      SUM = ABS( AB( I, J ) )
-                     IF( VALUE .LT. SUM .OR.
-     $                   SISNAN( SUM ) ) VALUE = SUM
+                     IF( VALUE .LT. SUM .OR. SISNAN( SUM ) ) VALUE = SUM
    10             CONTINUE
    20          CONTINUE
             ELSE
                DO 40 J = 1, N
                   DO 30 I = 2, MIN( N+1-J, K+1 )
                      SUM = ABS( AB( I, J ) )
-                     IF( VALUE .LT. SUM .OR.
-     $                   SISNAN( SUM ) ) VALUE = SUM
+                     IF( VALUE .LT. SUM .OR. SISNAN( SUM ) ) VALUE = SUM
    30             CONTINUE
    40          CONTINUE
             END IF
@@ -206,16 +207,14 @@
                DO 60 J = 1, N
                   DO 50 I = MAX( K+2-J, 1 ), K + 1
                      SUM = ABS( AB( I, J ) )
-                     IF( VALUE .LT. SUM .OR.
-     $                   SISNAN( SUM ) ) VALUE = SUM
+                     IF( VALUE .LT. SUM .OR. SISNAN( SUM ) ) VALUE = SUM
    50             CONTINUE
    60          CONTINUE
             ELSE
                DO 80 J = 1, N
                   DO 70 I = 1, MIN( N+1-J, K+1 )
                      SUM = ABS( AB( I, J ) )
-                     IF( VALUE .LT. SUM .OR.
-     $                   SISNAN( SUM ) ) VALUE = SUM
+                     IF( VALUE .LT. SUM .OR. SISNAN( SUM ) ) VALUE = SUM
    70             CONTINUE
    80          CONTINUE
             END IF
@@ -311,15 +310,14 @@
             SUM = WORK( I )
             IF( VALUE .LT. SUM .OR. SISNAN( SUM ) ) VALUE = SUM
   270    CONTINUE
-      ELSE IF( ( LSAME( NORM, 'F' ) ) .OR.
-     $         ( LSAME( NORM, 'E' ) ) ) THEN
+      ELSE IF( ( LSAME( NORM, 'F' ) ) .OR. ( LSAME( NORM, 'E' ) ) ) THEN
 *
 *        Find normF(A).
 *
          IF( LSAME( UPLO, 'U' ) ) THEN
             IF( LSAME( DIAG, 'U' ) ) THEN
                SCALE = ONE
-               SUM = REAL( N )
+               SUM = N
                IF( K.GT.0 ) THEN
                   DO 280 J = 2, N
                      CALL CLASSQ( MIN( J-1, K ),
@@ -331,19 +329,17 @@
                SCALE = ZERO
                SUM = ONE
                DO 290 J = 1, N
-                  CALL CLASSQ( MIN( J, K+1 ), AB( MAX( K+2-J, 1 ),
-     $                         J ),
+                  CALL CLASSQ( MIN( J, K+1 ), AB( MAX( K+2-J, 1 ), J ),
      $                         1, SCALE, SUM )
   290          CONTINUE
             END IF
          ELSE
             IF( LSAME( DIAG, 'U' ) ) THEN
                SCALE = ONE
-               SUM = REAL( N )
+               SUM = N
                IF( K.GT.0 ) THEN
                   DO 300 J = 1, N - 1
-                     CALL CLASSQ( MIN( N-J, K ), AB( 2, J ), 1,
-     $                            SCALE,
+                     CALL CLASSQ( MIN( N-J, K ), AB( 2, J ), 1, SCALE,
      $                            SUM )
   300             CONTINUE
                END IF
@@ -351,8 +347,7 @@
                SCALE = ZERO
                SUM = ONE
                DO 310 J = 1, N
-                  CALL CLASSQ( MIN( N-J+1, K+1 ), AB( 1, J ), 1,
-     $                         SCALE,
+                  CALL CLASSQ( MIN( N-J+1, K+1 ), AB( 1, J ), 1, SCALE,
      $                         SUM )
   310          CONTINUE
             END IF
