@@ -38,7 +38,7 @@
 *> SSYTRF_AA_2STAGE computes the factorization of a real symmetric matrix A
 *> using the Aasen's algorithm.  The form of the factorization is
 *>
-*>    A = U**T*T*U  or  A = L*T*L**T
+*>    A = U*T*U**T  or  A = L*T*L**T
 *>
 *> where U (or L) is a product of permutation and unit upper (lower)
 *> triangular matrices, and T is a symmetric band matrix with the
@@ -75,7 +75,7 @@
 *>          triangular part of the matrix A, and the strictly upper
 *>          triangular part of A is not referenced.
 *>
-*>          On exit, L is stored below (or above) the subdiagonal blocks,
+*>          On exit, L is stored below (or above) the subdiaonal blocks,
 *>          when UPLO  is 'L' (or 'U').
 *> \endverbatim
 *>
@@ -93,7 +93,6 @@
 *>
 *> \param[in] LTB
 *> \verbatim
-*>          LTB is INTEGER
 *>          The size of the array TB. LTB >= 4*N, internally
 *>          used to select NB such that LTB >= (3*NB+1)*N.
 *>
@@ -113,7 +112,7 @@
 *>
 *> \param[out] IPIV2
 *> \verbatim
-*>          IPIV2 is INTEGER array, dimension (N)
+*>          IPIV is INTEGER array, dimension (N)
 *>          On exit, it contains the details of the interchanges, i.e.,
 *>          the row and column k of T were interchanged with the
 *>          row and column IPIV(k).
@@ -126,7 +125,6 @@
 *>
 *> \param[in] LWORK
 *> \verbatim
-*>          LWORK is INTEGER
 *>          The size of WORK. LWORK >= N, internally used to select NB
 *>          such that LWORK >= N*NB.
 *>
@@ -152,15 +150,18 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup hetrf_aa_2stage
+*> \date November 2017
+*
+*> \ingroup realSYcomputational
 *
 *  =====================================================================
       SUBROUTINE SSYTRF_AA_2STAGE( UPLO, N, A, LDA, TB, LTB, IPIV,
      $                             IPIV2, WORK, LWORK, INFO )
 *
-*  -- LAPACK computational routine --
+*  -- LAPACK computational routine (version 3.8.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2017
 *
       IMPLICIT NONE
 *
@@ -187,11 +188,10 @@
 *     .. External Functions ..
       LOGICAL            LSAME
       INTEGER            ILAENV
-      REAL               SROUNDUP_LWORK
-      EXTERNAL           LSAME, ILAENV, SROUNDUP_LWORK
+      EXTERNAL           LSAME, ILAENV
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           XERBLA, SCOPY, SLACPY,
+      EXTERNAL           XERBLA, SCOPY, SLACGV, SLACPY,
      $                   SLASET, SGBTRF, SGEMM,  SGETRF, 
      $                   SSYGST, SSWAP, STRSM 
 *     ..
@@ -231,7 +231,7 @@
             TB( 1 ) = (3*NB+1)*N
          END IF
          IF( WQUERY ) THEN
-            WORK( 1 ) = SROUNDUP_LWORK(N*NB)
+            WORK( 1 ) = N*NB
          END IF
       END IF
       IF( TQUERY .OR. WQUERY ) THEN
@@ -273,7 +273,7 @@
       IF( UPPER ) THEN
 *
 *        .....................................................
-*        Factorize A as U**T*D*U using the upper triangle of A
+*        Factorize A as L*D*L**T using the upper triangle of A
 *        .....................................................
 *
          DO J = 0, NT-1
@@ -440,14 +440,12 @@ c               END IF
 *                    > Apply pivots to previous columns of L
                      CALL SSWAP( K-1, A( (J+1)*NB+1, I1 ), 1, 
      $                                A( (J+1)*NB+1, I2 ), 1 )
-*                    > Swap A(I1+1:M, I1) with A(I2, I1+1:M)
-                     IF( I2.GT.(I1+1) )
-     $                  CALL SSWAP( I2-I1-1, A( I1, I1+1 ), LDA,
-     $                                       A( I1+1, I2 ), 1 )
+*                    > Swap A(I1+1:M, I1) with A(I2, I1+1:M)               
+                     CALL SSWAP( I2-I1-1, A( I1, I1+1 ), LDA,
+     $                                    A( I1+1, I2 ), 1 )
 *                    > Swap A(I2+1:M, I1) with A(I2+1:M, I2)
-                     IF( I2.LT.N )
-     $                  CALL SSWAP( N-I2, A( I1, I2+1 ), LDA,
-     $                                    A( I2, I2+1 ), LDA ) 
+                     CALL SSWAP( N-I2, A( I1, I2+1 ), LDA,
+     $                                 A( I2, I2+1 ), LDA ) 
 *                    > Swap A(I1, I1) with A(I2, I2)
                      PIV = A( I1, I1 )
                      A( I1, I1 ) = A( I2, I2 )
@@ -616,13 +614,11 @@ c               END IF
                      CALL SSWAP( K-1, A( I1, (J+1)*NB+1 ), LDA, 
      $                                A( I2, (J+1)*NB+1 ), LDA )
 *                    > Swap A(I1+1:M, I1) with A(I2, I1+1:M)               
-                     IF( I2.GT.(I1+1) )
-     $                  CALL SSWAP( I2-I1-1, A( I1+1, I1 ), 1,
-     $                                       A( I2, I1+1 ), LDA )
+                     CALL SSWAP( I2-I1-1, A( I1+1, I1 ), 1,
+     $                                    A( I2, I1+1 ), LDA )
 *                    > Swap A(I2+1:M, I1) with A(I2+1:M, I2)
-                     IF( I2.LT.N )
-     $                  CALL SSWAP( N-I2, A( I2+1, I1 ), 1,
-     $                                    A( I2+1, I2 ), 1 ) 
+                     CALL SSWAP( N-I2, A( I2+1, I1 ), 1,
+     $                                 A( I2+1, I2 ), 1 ) 
 *                    > Swap A(I1, I1) with A(I2, I2)
                      PIV = A( I1, I1 )
                      A( I1, I1 ) = A( I2, I2 )
@@ -645,8 +641,6 @@ c     $                     (J+1)*NB+1, (J+1)*NB+KB, IPIV, 1 )
 *
 *     Factor the band matrix
       CALL SGBTRF( N, N, NB, NB, TB, LDTB, IPIV2, INFO )
-*
-      RETURN
 *
 *     End of SSYTRF_AA_2STAGE
 *
