@@ -1,4 +1,4 @@
-*> \brief \b DLAED4 used by DSTEDC. Finds a single root of the secular equation.
+*> \brief \b DLAED4 used by sstedc. Finds a single root of the secular equation.
 *
 *  =========== DOCUMENTATION ===========
 *
@@ -132,7 +132,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup laed4
+*> \ingroup auxOTHERcomputational
 *
 *> \par Contributors:
 *  ==================
@@ -328,12 +328,9 @@
          IF( C.LT.ZERO )
      $      C = ABS( C )
          IF( C.EQ.ZERO ) THEN
-*           ETA = B/A
+*          ETA = B/A
 *           ETA = RHO - TAU
-*           ETA = DLTUB - TAU
-*
-*           Update proposed by Li, Ren-Cang:
-            ETA = -W / ( DPSI+DPHI )
+            ETA = DLTUB - TAU
          ELSE IF( A.GE.ZERO ) THEN
             ETA = ( A+SQRT( ABS( A*A-FOUR*B*C ) ) ) / ( TWO*C )
          ELSE
