@@ -350,7 +350,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup tgsja
+*> \ingroup realOTHERcomputational
 *
 *> \par Further Details:
 *  =====================
@@ -397,7 +397,7 @@
 *     .. Parameters ..
       INTEGER            MAXIT
       PARAMETER          ( MAXIT = 40 )
-      REAL               ZERO, ONE, HUGENUM
+      REAL               ZERO, ONE
       PARAMETER          ( ZERO = 0.0E+0, ONE = 1.0E+0 )
 *     ..
 *     .. Local Scalars ..
@@ -416,8 +416,7 @@
      $                   SSCAL, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ABS, MAX, MIN, HUGE
-      PARAMETER          ( HUGENUM = HUGE(ZERO) )
+      INTRINSIC          ABS, MAX, MIN
 *     ..
 *     .. Executable Statements ..
 *
@@ -594,9 +593,9 @@
 *
          A1 = A( K+I, N-L+I )
          B1 = B( I, N-L+I )
-         GAMMA = B1 / A1
 *
-         IF( (GAMMA.LE.HUGENUM).AND.(GAMMA.GE.-HUGENUM) ) THEN
+         IF( A1.NE.ZERO ) THEN
+            GAMMA = B1 / A1
 *
 *           change sign if necessary
 *
