@@ -28,7 +28,6 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function cherfsx
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
@@ -52,28 +51,30 @@ lapack_int LAPACKE_cherfsx( int matrix_layout, char uplo, char equed,
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_che_nancheck( matrix_layout, uplo, n, a, lda ) ) {
-        return -6;
-    }
-    if( LAPACKE_che_nancheck( matrix_layout, uplo, n, af, ldaf ) ) {
-        return -8;
-    }
-    if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
-        return -12;
-    }
-    if( nparams>0 ) {
-        if( LAPACKE_s_nancheck( nparams, params, 1 ) ) {
-            return -22;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( LAPACKE_che_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+            return -6;
         }
-    }
-    if( LAPACKE_lsame( equed, 'y' ) ) {
-        if( LAPACKE_s_nancheck( n, s, 1 ) ) {
-            return -11;
+        if( LAPACKE_che_nancheck( matrix_layout, uplo, n, af, ldaf ) ) {
+            return -8;
+        }
+        if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+            return -12;
+        }
+        if( nparams>0 ) {
+            if( LAPACKE_s_nancheck( nparams, params, 1 ) ) {
+                return -22;
+            }
+        }
+        if( LAPACKE_lsame( equed, 'y' ) ) {
+            if( LAPACKE_s_nancheck( n, s, 1 ) ) {
+                return -11;
+            }
+        }
+        if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, x, ldx ) ) {
+            return -14;
         }
-    }
-    if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, x, ldx ) ) {
-        return -14;
     }
 #endif
     /* Allocate memory for working array(s) */
