@@ -32,26 +32,26 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_ztbtrs( int matrix_layout, char uplo, char trans, char diag,
+lapack_int API_SUFFIX(LAPACKE_ztbtrs)( int matrix_layout, char uplo, char trans, char diag,
                            lapack_int n, lapack_int kd, lapack_int nrhs,
                            const lapack_complex_double* ab, lapack_int ldab,
                            lapack_complex_double* b, lapack_int ldb )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_ztbtrs", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_ztbtrs", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_ztb_nancheck( matrix_layout, uplo, diag, n, kd, ab, ldab ) ) {
+        if( API_SUFFIX(LAPACKE_ztb_nancheck)( matrix_layout, uplo, diag, n, kd, ab, ldab ) ) {
             return -8;
         }
-        if( LAPACKE_zge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -10;
         }
     }
 #endif
-    return LAPACKE_ztbtrs_work( matrix_layout, uplo, trans, diag, n, kd, nrhs,
+    return API_SUFFIX(LAPACKE_ztbtrs_work)( matrix_layout, uplo, trans, diag, n, kd, nrhs,
                                 ab, ldab, b, ldb );
 }
