@@ -28,7 +28,7 @@
 ******************************************************************************
 * Contents: Native high-level C interface to LAPACK function zgemqrt
 * Author: Intel Corporation
-* Generated June 2016
+* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
@@ -40,7 +40,6 @@ lapack_int LAPACKE_zgemqrt( int matrix_layout, char side, char trans,
                             lapack_int ldt, lapack_complex_double* c,
                             lapack_int ldc )
 {
-    lapack_int nrows_v;
     lapack_int info = 0;
     lapack_complex_double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
@@ -49,15 +48,13 @@ lapack_int LAPACKE_zgemqrt( int matrix_layout, char side, char trans,
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     /* Optionally check input matrices for NaNs */
-    nrows_v = LAPACKE_lsame( side, 'L' ) ? m :
-                         ( LAPACKE_lsame( side, 'R' ) ? n : 0 );
     if( LAPACKE_zge_nancheck( matrix_layout, m, n, c, ldc ) ) {
         return -12;
     }
-    if( LAPACKE_zge_nancheck( matrix_layout, nb, k, t, ldt ) ) {
+    if( LAPACKE_zge_nancheck( matrix_layout, ldt, nb, t, ldt ) ) {
         return -10;
     }
-    if( LAPACKE_zge_nancheck( matrix_layout, nrows_v, k, v, ldv ) ) {
+    if( LAPACKE_zge_nancheck( matrix_layout, ldv, k, v, ldv ) ) {
         return -8;
     }
 #endif
