@@ -28,7 +28,7 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function zuncsd2by1
 * Author: Intel Corporation
-* Generated June 2016
+* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
@@ -37,10 +37,10 @@ lapack_int LAPACKE_zuncsd2by1_work( int matrix_layout, char jobu1, char jobu2,
                                 char jobv1t, lapack_int m, lapack_int p,
                                 lapack_int q, lapack_complex_double* x11, lapack_int ldx11,
                                 lapack_complex_double* x21, lapack_int ldx21,
-                                double* theta, lapack_complex_double* u1,
-                                lapack_int ldu1, lapack_complex_double* u2,
+                                lapack_complex_double* theta, lapack_complex_double* u1,
+                                lapack_int ldu1, lapack_complex_double* u2, 
                                 lapack_int ldu2, lapack_complex_double* v1t,
-                                lapack_int ldv1t, lapack_complex_double* work,
+                                lapack_int ldv1t, lapack_complex_double* work, 
                                 lapack_int lwork, double* rwork, lapack_int lrwork,
                                 lapack_int* iwork )
 {
@@ -48,8 +48,8 @@ lapack_int LAPACKE_zuncsd2by1_work( int matrix_layout, char jobu1, char jobu2,
     if( matrix_layout == LAPACK_COL_MAJOR ) {
         /* Call LAPACK function and adjust info */
         LAPACK_zuncsd2by1( &jobu1, &jobu2, &jobv1t, &m, &p,
-                       &q, x11, &ldx11, x21, &ldx21,
-                       theta, u1, &ldu1, u2, &ldu2, v1t, &ldv1t,
+                       &q, x11, &ldx11, x21, &ldx21, 
+                       theta, u1, &ldu1, u2, &ldu2, v1t, &ldv1t, 
                        work, &lwork, rwork, &lrwork, iwork, &info );
         if( info < 0 ) {
             info = info - 1;
@@ -99,8 +99,8 @@ lapack_int LAPACKE_zuncsd2by1_work( int matrix_layout, char jobu1, char jobu2,
         /* Query optimal working array(s) size if requested */
         if( lrwork == -1 || lwork == -1 ) {
             LAPACK_zuncsd2by1( &jobu1, &jobu2, &jobv1t, &m, &p,
-                       &q, x11, &ldx11_t, x21, &ldx21_t,
-                       theta, u1, &ldu1_t, u2, &ldu2_t, v1t, &ldv1t_t,
+                       &q, x11, &ldx11, x21, &ldx21, 
+                       theta, u1, &ldu1, u2, &ldu2, v1t, &ldv1t, 
                        work, &lwork, rwork, &lrwork, iwork, &info );
             return (info < 0) ? (info - 1) : info;
         }
@@ -146,8 +146,8 @@ lapack_int LAPACKE_zuncsd2by1_work( int matrix_layout, char jobu1, char jobu2,
                            ldx21_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zuncsd2by1( &jobu1, &jobu2, &jobv1t, &m, &p,
-                       &q, x11_t, &ldx11_t, x21_t, &ldx21_t,
-                       theta, u1_t, &ldu1_t, u2_t, &ldu2_t, v1t_t, &ldv1t_t,
+                       &q, x11, &ldx11, x21, &ldx21, 
+                       theta, u1, &ldu1, u2, &ldu2, v1t, &ldv1t, 
                        work, &lwork, rwork, &lrwork, iwork, &info );
         if( info < 0 ) {
             info = info - 1;
