@@ -28,11 +28,12 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function dggrqf
 * Author: Intel Corporation
+* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int API_SUFFIX(LAPACKE_dggrqf)( int matrix_layout, lapack_int m, lapack_int p,
+lapack_int LAPACKE_dggrqf( int matrix_layout, lapack_int m, lapack_int p,
                            lapack_int n, double* a, lapack_int lda,
                            double* taua, double* b, lapack_int ldb,
                            double* taub )
@@ -42,22 +43,20 @@ lapack_int API_SUFFIX(LAPACKE_dggrqf)( int matrix_layout, lapack_int m, lapack_i
     double* work = NULL;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dggrqf", -1 );
+        LAPACKE_xerbla( "LAPACKE_dggrqf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    if( LAPACKE_get_nancheck() ) {
-        /* Optionally check input matrices for NaNs */
-        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, m, n, a, lda ) ) {
-            return -5;
-        }
-        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, p, n, b, ldb ) ) {
-            return -8;
-        }
+    /* Optionally check input matrices for NaNs */
+    if( LAPACKE_dge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        return -5;
+    }
+    if( LAPACKE_dge_nancheck( matrix_layout, p, n, b, ldb ) ) {
+        return -8;
     }
 #endif
     /* Query optimal working array(s) size */
-    info = API_SUFFIX(LAPACKE_dggrqf_work)( matrix_layout, m, p, n, a, lda, taua, b, ldb,
+    info = LAPACKE_dggrqf_work( matrix_layout, m, p, n, a, lda, taua, b, ldb,
                                 taub, &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -70,13 +69,13 @@ lapack_int API_SUFFIX(LAPACKE_dggrqf)( int matrix_layout, lapack_int m, lapack_i
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = API_SUFFIX(LAPACKE_dggrqf_work)( matrix_layout, m, p, n, a, lda, taua, b, ldb,
+    info = LAPACKE_dggrqf_work( matrix_layout, m, p, n, a, lda, taua, b, ldb,
                                 taub, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dggrqf", info );
+        LAPACKE_xerbla( "LAPACKE_dggrqf", info );
     }
     return info;
 }
