@@ -25,7 +25,7 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 10
+#define FLEXIBLAS_LAPACK_MINOR 6
 #define FLEXIBLAS_LAPACK_PATCH 1
 #define FLEXIBLAS_LAPACK_EXTRA with deprecated
 
@@ -67,25 +67,18 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgehd2;
     flexiblas_blasfn cgehrd;
     flexiblas_blasfn cgejsv;
-    flexiblas_blasfn cgelq;
     flexiblas_blasfn cgelq2;
     flexiblas_blasfn cgelqf;
-    flexiblas_blasfn cgelqt;
-    flexiblas_blasfn cgelqt3;
     flexiblas_blasfn cgels;
     flexiblas_blasfn cgelsd;
     flexiblas_blasfn cgelss;
     flexiblas_blasfn cgelsx;
     flexiblas_blasfn cgelsy;
-    flexiblas_blasfn cgemlq;
-    flexiblas_blasfn cgemlqt;
-    flexiblas_blasfn cgemqr;
     flexiblas_blasfn cgemqrt;
     flexiblas_blasfn cgeql2;
     flexiblas_blasfn cgeqlf;
     flexiblas_blasfn cgeqp3;
     flexiblas_blasfn cgeqpf;
-    flexiblas_blasfn cgeqr;
     flexiblas_blasfn cgeqr2;
     flexiblas_blasfn cgeqr2p;
     flexiblas_blasfn cgeqrf;
@@ -100,7 +93,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgesdd;
     flexiblas_blasfn cgesv;
     flexiblas_blasfn cgesvd;
-    flexiblas_blasfn cgesvdq;
     flexiblas_blasfn cgesvdx;
     flexiblas_blasfn cgesvj;
     flexiblas_blasfn cgesvx;
@@ -110,8 +102,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgetrf2;
     flexiblas_blasfn cgetri;
     flexiblas_blasfn cgetrs;
-    flexiblas_blasfn cgetsls;
-    flexiblas_blasfn cgetsqrhrt;
     flexiblas_blasfn cggbak;
     flexiblas_blasfn cggbal;
     flexiblas_blasfn cgges;
@@ -139,68 +129,43 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgttrf;
     flexiblas_blasfn cgttrs;
     flexiblas_blasfn cgtts2;
-    flexiblas_blasfn chb2st_kernels;
     flexiblas_blasfn chbev;
-    flexiblas_blasfn chbev_2stage;
     flexiblas_blasfn chbevd;
-    flexiblas_blasfn chbevd_2stage;
     flexiblas_blasfn chbevx;
-    flexiblas_blasfn chbevx_2stage;
     flexiblas_blasfn chbgst;
     flexiblas_blasfn chbgv;
     flexiblas_blasfn chbgvd;
     flexiblas_blasfn chbgvx;
     flexiblas_blasfn chbtrd;
     flexiblas_blasfn checon;
-    flexiblas_blasfn checon_3;
     flexiblas_blasfn checon_rook;
     flexiblas_blasfn cheequb;
     flexiblas_blasfn cheev;
-    flexiblas_blasfn cheev_2stage;
     flexiblas_blasfn cheevd;
-    flexiblas_blasfn cheevd_2stage;
     flexiblas_blasfn cheevr;
-    flexiblas_blasfn cheevr_2stage;
     flexiblas_blasfn cheevx;
-    flexiblas_blasfn cheevx_2stage;
     flexiblas_blasfn chegs2;
     flexiblas_blasfn chegst;
     flexiblas_blasfn chegv;
-    flexiblas_blasfn chegv_2stage;
     flexiblas_blasfn chegvd;
     flexiblas_blasfn chegvx;
     flexiblas_blasfn cherfs;
     flexiblas_blasfn chesv;
-    flexiblas_blasfn chesv_aa;
-    flexiblas_blasfn chesv_aa_2stage;
-    flexiblas_blasfn chesv_rk;
     flexiblas_blasfn chesv_rook;
     flexiblas_blasfn chesvx;
     flexiblas_blasfn cheswapr;
     flexiblas_blasfn chetd2;
     flexiblas_blasfn chetf2;
-    flexiblas_blasfn chetf2_rk;
     flexiblas_blasfn chetf2_rook;
     flexiblas_blasfn chetrd;
-    flexiblas_blasfn chetrd_2stage;
-    flexiblas_blasfn chetrd_hb2st;
-    flexiblas_blasfn chetrd_he2hb;
     flexiblas_blasfn chetrf;
-    flexiblas_blasfn chetrf_aa;
-    flexiblas_blasfn chetrf_aa_2stage;
-    flexiblas_blasfn chetrf_rk;
     flexiblas_blasfn chetrf_rook;
     flexiblas_blasfn chetri;
     flexiblas_blasfn chetri2;
     flexiblas_blasfn chetri2x;
-    flexiblas_blasfn chetri_3;
-    flexiblas_blasfn chetri_3x;
     flexiblas_blasfn chetri_rook;
     flexiblas_blasfn chetrs;
     flexiblas_blasfn chetrs2;
-    flexiblas_blasfn chetrs_3;
-    flexiblas_blasfn chetrs_aa;
-    flexiblas_blasfn chetrs_aa_2stage;
     flexiblas_blasfn chetrs_rook;
     flexiblas_blasfn chfrk;
     flexiblas_blasfn chgeqz;
@@ -241,8 +206,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn clags2;
     flexiblas_blasfn clagtm;
     flexiblas_blasfn clahef;
-    flexiblas_blasfn clahef_aa;
-    flexiblas_blasfn clahef_rk;
     flexiblas_blasfn clahef_rook;
     flexiblas_blasfn clahqr;
     flexiblas_blasfn clahr2;
@@ -251,8 +214,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn clals0;
     flexiblas_blasfn clalsa;
     flexiblas_blasfn clalsd;
-    flexiblas_blasfn clamswlq;
-    flexiblas_blasfn clamtsqr;
     flexiblas_blasfn clangb;
     flexiblas_blasfn clange;
     flexiblas_blasfn clangt;
@@ -287,21 +248,15 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn claqsb;
     flexiblas_blasfn claqsp;
     flexiblas_blasfn claqsy;
-    flexiblas_blasfn claqz0;
-    flexiblas_blasfn claqz1;
-    flexiblas_blasfn claqz2;
-    flexiblas_blasfn claqz3;
     flexiblas_blasfn clar1v;
     flexiblas_blasfn clar2v;
     flexiblas_blasfn clarcm;
     flexiblas_blasfn clarf;
     flexiblas_blasfn clarfb;
-    flexiblas_blasfn clarfb_gett;
     flexiblas_blasfn clarfg;
     flexiblas_blasfn clarfgp;
     flexiblas_blasfn clarft;
     flexiblas_blasfn clarfx;
-    flexiblas_blasfn clarfy;
     flexiblas_blasfn clargv;
     flexiblas_blasfn clarnv;
     flexiblas_blasfn clarrv;
@@ -314,11 +269,8 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn claset;
     flexiblas_blasfn clasr;
     flexiblas_blasfn classq;
-    flexiblas_blasfn claswlq;
     flexiblas_blasfn claswp;
     flexiblas_blasfn clasyf;
-    flexiblas_blasfn clasyf_aa;
-    flexiblas_blasfn clasyf_rk;
     flexiblas_blasfn clasyf_rook;
     flexiblas_blasfn clatbs;
     flexiblas_blasfn clatdf;
@@ -326,10 +278,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn clatrd;
     flexiblas_blasfn clatrs;
     flexiblas_blasfn clatrz;
-    flexiblas_blasfn clatsqr;
     flexiblas_blasfn clatzm;
-    flexiblas_blasfn claunhr_col_getrfnp;
-    flexiblas_blasfn claunhr_col_getrfnp2;
     flexiblas_blasfn clauu2;
     flexiblas_blasfn clauum;
     flexiblas_blasfn cpbcon;
@@ -390,41 +339,26 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cstemr;
     flexiblas_blasfn csteqr;
     flexiblas_blasfn csycon;
-    flexiblas_blasfn csycon_3;
     flexiblas_blasfn csycon_rook;
     flexiblas_blasfn csyconv;
-    flexiblas_blasfn csyconvf;
-    flexiblas_blasfn csyconvf_rook;
     flexiblas_blasfn csyequb;
     flexiblas_blasfn csymv;
     flexiblas_blasfn csyr;
     flexiblas_blasfn csyrfs;
     flexiblas_blasfn csysv;
-    flexiblas_blasfn csysv_aa;
-    flexiblas_blasfn csysv_aa_2stage;
-    flexiblas_blasfn csysv_rk;
     flexiblas_blasfn csysv_rook;
     flexiblas_blasfn csysvx;
     flexiblas_blasfn csyswapr;
     flexiblas_blasfn csytf2;
-    flexiblas_blasfn csytf2_rk;
     flexiblas_blasfn csytf2_rook;
     flexiblas_blasfn csytrf;
-    flexiblas_blasfn csytrf_aa;
-    flexiblas_blasfn csytrf_aa_2stage;
-    flexiblas_blasfn csytrf_rk;
     flexiblas_blasfn csytrf_rook;
     flexiblas_blasfn csytri;
     flexiblas_blasfn csytri2;
     flexiblas_blasfn csytri2x;
-    flexiblas_blasfn csytri_3;
-    flexiblas_blasfn csytri_3x;
     flexiblas_blasfn csytri_rook;
     flexiblas_blasfn csytrs;
     flexiblas_blasfn csytrs2;
-    flexiblas_blasfn csytrs_3;
-    flexiblas_blasfn csytrs_aa;
-    flexiblas_blasfn csytrs_aa_2stage;
     flexiblas_blasfn csytrs_rook;
     flexiblas_blasfn ctbcon;
     flexiblas_blasfn ctbrfs;
@@ -442,9 +376,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ctgsy2;
     flexiblas_blasfn ctgsyl;
     flexiblas_blasfn ctpcon;
-    flexiblas_blasfn ctplqt;
-    flexiblas_blasfn ctplqt2;
-    flexiblas_blasfn ctpmlqt;
     flexiblas_blasfn ctpmqrt;
     flexiblas_blasfn ctpqrt;
     flexiblas_blasfn ctpqrt2;
@@ -489,9 +420,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cungr2;
     flexiblas_blasfn cungrq;
     flexiblas_blasfn cungtr;
-    flexiblas_blasfn cungtsqr;
-    flexiblas_blasfn cungtsqr_row;
-    flexiblas_blasfn cunhr_col;
     flexiblas_blasfn cunm22;
     flexiblas_blasfn cunm2l;
     flexiblas_blasfn cunm2r;
@@ -539,25 +467,18 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgehd2;
     flexiblas_blasfn dgehrd;
     flexiblas_blasfn dgejsv;
-    flexiblas_blasfn dgelq;
     flexiblas_blasfn dgelq2;
     flexiblas_blasfn dgelqf;
-    flexiblas_blasfn dgelqt;
-    flexiblas_blasfn dgelqt3;
     flexiblas_blasfn dgels;
     flexiblas_blasfn dgelsd;
     flexiblas_blasfn dgelss;
     flexiblas_blasfn dgelsx;
     flexiblas_blasfn dgelsy;
-    flexiblas_blasfn dgemlq;
-    flexiblas_blasfn dgemlqt;
-    flexiblas_blasfn dgemqr;
     flexiblas_blasfn dgemqrt;
     flexiblas_blasfn dgeql2;
     flexiblas_blasfn dgeqlf;
     flexiblas_blasfn dgeqp3;
     flexiblas_blasfn dgeqpf;
-    flexiblas_blasfn dgeqr;
     flexiblas_blasfn dgeqr2;
     flexiblas_blasfn dgeqr2p;
     flexiblas_blasfn dgeqrf;
@@ -572,7 +493,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgesdd;
     flexiblas_blasfn dgesv;
     flexiblas_blasfn dgesvd;
-    flexiblas_blasfn dgesvdq;
     flexiblas_blasfn dgesvdx;
     flexiblas_blasfn dgesvj;
     flexiblas_blasfn dgesvx;
@@ -582,8 +502,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgetrf2;
     flexiblas_blasfn dgetri;
     flexiblas_blasfn dgetrs;
-    flexiblas_blasfn dgetsls;
-    flexiblas_blasfn dgetsqrhrt;
     flexiblas_blasfn dggbak;
     flexiblas_blasfn dggbal;
     flexiblas_blasfn dgges;
@@ -658,8 +576,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlamc3;
     flexiblas_blasfn dlamch;
     flexiblas_blasfn dlamrg;
-    flexiblas_blasfn dlamswlq;
-    flexiblas_blasfn dlamtsqr;
     flexiblas_blasfn dlaneg;
     flexiblas_blasfn dlangb;
     flexiblas_blasfn dlange;
@@ -674,8 +590,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlantp;
     flexiblas_blasfn dlantr;
     flexiblas_blasfn dlanv2;
-    flexiblas_blasfn dlaorhr_col_getrfnp;
-    flexiblas_blasfn dlaorhr_col_getrfnp2;
     flexiblas_blasfn dlapll;
     flexiblas_blasfn dlapmr;
     flexiblas_blasfn dlapmt;
@@ -695,21 +609,14 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlaqsp;
     flexiblas_blasfn dlaqsy;
     flexiblas_blasfn dlaqtr;
-    flexiblas_blasfn dlaqz0;
-    flexiblas_blasfn dlaqz1;
-    flexiblas_blasfn dlaqz2;
-    flexiblas_blasfn dlaqz3;
-    flexiblas_blasfn dlaqz4;
     flexiblas_blasfn dlar1v;
     flexiblas_blasfn dlar2v;
     flexiblas_blasfn dlarf;
     flexiblas_blasfn dlarfb;
-    flexiblas_blasfn dlarfb_gett;
     flexiblas_blasfn dlarfg;
     flexiblas_blasfn dlarfgp;
     flexiblas_blasfn dlarft;
     flexiblas_blasfn dlarfx;
-    flexiblas_blasfn dlarfy;
     flexiblas_blasfn dlargv;
     flexiblas_blasfn dlarnv;
     flexiblas_blasfn dlarra;
@@ -755,12 +662,9 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlasrt;
     flexiblas_blasfn dlassq;
     flexiblas_blasfn dlasv2;
-    flexiblas_blasfn dlaswlq;
     flexiblas_blasfn dlaswp;
     flexiblas_blasfn dlasy2;
     flexiblas_blasfn dlasyf;
-    flexiblas_blasfn dlasyf_aa;
-    flexiblas_blasfn dlasyf_rk;
     flexiblas_blasfn dlasyf_rook;
     flexiblas_blasfn dlat2s;
     flexiblas_blasfn dlatbs;
@@ -769,7 +673,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlatrd;
     flexiblas_blasfn dlatrs;
     flexiblas_blasfn dlatrz;
-    flexiblas_blasfn dlatsqr;
     flexiblas_blasfn dlatzm;
     flexiblas_blasfn dlauu2;
     flexiblas_blasfn dlauum;
@@ -795,9 +698,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dorgr2;
     flexiblas_blasfn dorgrq;
     flexiblas_blasfn dorgtr;
-    flexiblas_blasfn dorgtsqr;
-    flexiblas_blasfn dorgtsqr_row;
-    flexiblas_blasfn dorhr_col;
     flexiblas_blasfn dorm22;
     flexiblas_blasfn dorm2l;
     flexiblas_blasfn dorm2r;
@@ -853,15 +753,10 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dpttrf;
     flexiblas_blasfn dpttrs;
     flexiblas_blasfn dptts2;
-    flexiblas_blasfn droundup_lwork;
     flexiblas_blasfn drscl;
-    flexiblas_blasfn dsb2st_kernels;
     flexiblas_blasfn dsbev;
-    flexiblas_blasfn dsbev_2stage;
     flexiblas_blasfn dsbevd;
-    flexiblas_blasfn dsbevd_2stage;
     flexiblas_blasfn dsbevx;
-    flexiblas_blasfn dsbevx_2stage;
     flexiblas_blasfn dsbgst;
     flexiblas_blasfn dsbgv;
     flexiblas_blasfn dsbgvd;
@@ -898,58 +793,35 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dstevr;
     flexiblas_blasfn dstevx;
     flexiblas_blasfn dsycon;
-    flexiblas_blasfn dsycon_3;
     flexiblas_blasfn dsycon_rook;
     flexiblas_blasfn dsyconv;
-    flexiblas_blasfn dsyconvf;
-    flexiblas_blasfn dsyconvf_rook;
     flexiblas_blasfn dsyequb;
     flexiblas_blasfn dsyev;
-    flexiblas_blasfn dsyev_2stage;
     flexiblas_blasfn dsyevd;
-    flexiblas_blasfn dsyevd_2stage;
     flexiblas_blasfn dsyevr;
-    flexiblas_blasfn dsyevr_2stage;
     flexiblas_blasfn dsyevx;
-    flexiblas_blasfn dsyevx_2stage;
     flexiblas_blasfn dsygs2;
     flexiblas_blasfn dsygst;
     flexiblas_blasfn dsygv;
-    flexiblas_blasfn dsygv_2stage;
     flexiblas_blasfn dsygvd;
     flexiblas_blasfn dsygvx;
     flexiblas_blasfn dsyrfs;
     flexiblas_blasfn dsysv;
-    flexiblas_blasfn dsysv_aa;
-    flexiblas_blasfn dsysv_aa_2stage;
-    flexiblas_blasfn dsysv_rk;
     flexiblas_blasfn dsysv_rook;
     flexiblas_blasfn dsysvx;
     flexiblas_blasfn dsyswapr;
     flexiblas_blasfn dsytd2;
     flexiblas_blasfn dsytf2;
-    flexiblas_blasfn dsytf2_rk;
     flexiblas_blasfn dsytf2_rook;
     flexiblas_blasfn dsytrd;
-    flexiblas_blasfn dsytrd_2stage;
-    flexiblas_blasfn dsytrd_sb2st;
-    flexiblas_blasfn dsytrd_sy2sb;
     flexiblas_blasfn dsytrf;
-    flexiblas_blasfn dsytrf_aa;
-    flexiblas_blasfn dsytrf_aa_2stage;
-    flexiblas_blasfn dsytrf_rk;
     flexiblas_blasfn dsytrf_rook;
     flexiblas_blasfn dsytri;
     flexiblas_blasfn dsytri2;
     flexiblas_blasfn dsytri2x;
-    flexiblas_blasfn dsytri_3;
-    flexiblas_blasfn dsytri_3x;
     flexiblas_blasfn dsytri_rook;
     flexiblas_blasfn dsytrs;
     flexiblas_blasfn dsytrs2;
-    flexiblas_blasfn dsytrs_3;
-    flexiblas_blasfn dsytrs_aa;
-    flexiblas_blasfn dsytrs_aa_2stage;
     flexiblas_blasfn dsytrs_rook;
     flexiblas_blasfn dtbcon;
     flexiblas_blasfn dtbrfs;
@@ -967,9 +839,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dtgsy2;
     flexiblas_blasfn dtgsyl;
     flexiblas_blasfn dtpcon;
-    flexiblas_blasfn dtplqt;
-    flexiblas_blasfn dtplqt2;
-    flexiblas_blasfn dtpmlqt;
     flexiblas_blasfn dtpmqrt;
     flexiblas_blasfn dtpqrt;
     flexiblas_blasfn dtpqrt2;
@@ -1003,7 +872,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn iladlc;
     flexiblas_blasfn iladlr;
     flexiblas_blasfn ilaenv;
-    flexiblas_blasfn ilaenv2stage;
     flexiblas_blasfn ilaprec;
     flexiblas_blasfn ilaslc;
     flexiblas_blasfn ilaslr;
@@ -1011,7 +879,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ilauplo;
     flexiblas_blasfn ilazlc;
     flexiblas_blasfn ilazlr;
-    flexiblas_blasfn iparam2stage;
     flexiblas_blasfn iparmq;
     flexiblas_blasfn izmax1;
     flexiblas_blasfn sbbcsd;
@@ -1047,25 +914,18 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgehd2;
     flexiblas_blasfn sgehrd;
     flexiblas_blasfn sgejsv;
-    flexiblas_blasfn sgelq;
     flexiblas_blasfn sgelq2;
     flexiblas_blasfn sgelqf;
-    flexiblas_blasfn sgelqt;
-    flexiblas_blasfn sgelqt3;
     flexiblas_blasfn sgels;
     flexiblas_blasfn sgelsd;
     flexiblas_blasfn sgelss;
     flexiblas_blasfn sgelsx;
     flexiblas_blasfn sgelsy;
-    flexiblas_blasfn sgemlq;
-    flexiblas_blasfn sgemlqt;
-    flexiblas_blasfn sgemqr;
     flexiblas_blasfn sgemqrt;
     flexiblas_blasfn sgeql2;
     flexiblas_blasfn sgeqlf;
     flexiblas_blasfn sgeqp3;
     flexiblas_blasfn sgeqpf;
-    flexiblas_blasfn sgeqr;
     flexiblas_blasfn sgeqr2;
     flexiblas_blasfn sgeqr2p;
     flexiblas_blasfn sgeqrf;
@@ -1080,7 +940,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgesdd;
     flexiblas_blasfn sgesv;
     flexiblas_blasfn sgesvd;
-    flexiblas_blasfn sgesvdq;
     flexiblas_blasfn sgesvdx;
     flexiblas_blasfn sgesvj;
     flexiblas_blasfn sgesvx;
@@ -1090,8 +949,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgetrf2;
     flexiblas_blasfn sgetri;
     flexiblas_blasfn sgetrs;
-    flexiblas_blasfn sgetsls;
-    flexiblas_blasfn sgetsqrhrt;
     flexiblas_blasfn sggbak;
     flexiblas_blasfn sggbal;
     flexiblas_blasfn sgges;
@@ -1166,8 +1023,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slamc3;
     flexiblas_blasfn slamch;
     flexiblas_blasfn slamrg;
-    flexiblas_blasfn slamswlq;
-    flexiblas_blasfn slamtsqr;
     flexiblas_blasfn slaneg;
     flexiblas_blasfn slangb;
     flexiblas_blasfn slange;
@@ -1182,8 +1037,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slantp;
     flexiblas_blasfn slantr;
     flexiblas_blasfn slanv2;
-    flexiblas_blasfn slaorhr_col_getrfnp;
-    flexiblas_blasfn slaorhr_col_getrfnp2;
     flexiblas_blasfn slapll;
     flexiblas_blasfn slapmr;
     flexiblas_blasfn slapmt;
@@ -1203,21 +1056,14 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slaqsp;
     flexiblas_blasfn slaqsy;
     flexiblas_blasfn slaqtr;
-    flexiblas_blasfn slaqz0;
-    flexiblas_blasfn slaqz1;
-    flexiblas_blasfn slaqz2;
-    flexiblas_blasfn slaqz3;
-    flexiblas_blasfn slaqz4;
     flexiblas_blasfn slar1v;
     flexiblas_blasfn slar2v;
     flexiblas_blasfn slarf;
     flexiblas_blasfn slarfb;
-    flexiblas_blasfn slarfb_gett;
     flexiblas_blasfn slarfg;
     flexiblas_blasfn slarfgp;
     flexiblas_blasfn slarft;
     flexiblas_blasfn slarfx;
-    flexiblas_blasfn slarfy;
     flexiblas_blasfn slargv;
     flexiblas_blasfn slarnv;
     flexiblas_blasfn slarra;
@@ -1263,12 +1109,9 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slasrt;
     flexiblas_blasfn slassq;
     flexiblas_blasfn slasv2;
-    flexiblas_blasfn slaswlq;
     flexiblas_blasfn slaswp;
     flexiblas_blasfn slasy2;
     flexiblas_blasfn slasyf;
-    flexiblas_blasfn slasyf_aa;
-    flexiblas_blasfn slasyf_rk;
     flexiblas_blasfn slasyf_rook;
     flexiblas_blasfn slatbs;
     flexiblas_blasfn slatdf;
@@ -1276,7 +1119,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slatrd;
     flexiblas_blasfn slatrs;
     flexiblas_blasfn slatrz;
-    flexiblas_blasfn slatsqr;
     flexiblas_blasfn slatzm;
     flexiblas_blasfn slauu2;
     flexiblas_blasfn slauum;
@@ -1302,9 +1144,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sorgr2;
     flexiblas_blasfn sorgrq;
     flexiblas_blasfn sorgtr;
-    flexiblas_blasfn sorgtsqr;
-    flexiblas_blasfn sorgtsqr_row;
-    flexiblas_blasfn sorhr_col;
     flexiblas_blasfn sorm22;
     flexiblas_blasfn sorm2l;
     flexiblas_blasfn sorm2r;
@@ -1360,15 +1199,10 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn spttrf;
     flexiblas_blasfn spttrs;
     flexiblas_blasfn sptts2;
-    flexiblas_blasfn sroundup_lwork;
     flexiblas_blasfn srscl;
-    flexiblas_blasfn ssb2st_kernels;
     flexiblas_blasfn ssbev;
-    flexiblas_blasfn ssbev_2stage;
     flexiblas_blasfn ssbevd;
-    flexiblas_blasfn ssbevd_2stage;
     flexiblas_blasfn ssbevx;
-    flexiblas_blasfn ssbevx_2stage;
     flexiblas_blasfn ssbgst;
     flexiblas_blasfn ssbgv;
     flexiblas_blasfn ssbgvd;
@@ -1402,58 +1236,35 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sstevr;
     flexiblas_blasfn sstevx;
     flexiblas_blasfn ssycon;
-    flexiblas_blasfn ssycon_3;
     flexiblas_blasfn ssycon_rook;
     flexiblas_blasfn ssyconv;
-    flexiblas_blasfn ssyconvf;
-    flexiblas_blasfn ssyconvf_rook;
     flexiblas_blasfn ssyequb;
     flexiblas_blasfn ssyev;
-    flexiblas_blasfn ssyev_2stage;
     flexiblas_blasfn ssyevd;
-    flexiblas_blasfn ssyevd_2stage;
     flexiblas_blasfn ssyevr;
-    flexiblas_blasfn ssyevr_2stage;
     flexiblas_blasfn ssyevx;
-    flexiblas_blasfn ssyevx_2stage;
     flexiblas_blasfn ssygs2;
     flexiblas_blasfn ssygst;
     flexiblas_blasfn ssygv;
-    flexiblas_blasfn ssygv_2stage;
     flexiblas_blasfn ssygvd;
     flexiblas_blasfn ssygvx;
     flexiblas_blasfn ssyrfs;
     flexiblas_blasfn ssysv;
-    flexiblas_blasfn ssysv_aa;
-    flexiblas_blasfn ssysv_aa_2stage;
-    flexiblas_blasfn ssysv_rk;
     flexiblas_blasfn ssysv_rook;
     flexiblas_blasfn ssysvx;
     flexiblas_blasfn ssyswapr;
     flexiblas_blasfn ssytd2;
     flexiblas_blasfn ssytf2;
-    flexiblas_blasfn ssytf2_rk;
     flexiblas_blasfn ssytf2_rook;
     flexiblas_blasfn ssytrd;
-    flexiblas_blasfn ssytrd_2stage;
-    flexiblas_blasfn ssytrd_sb2st;
-    flexiblas_blasfn ssytrd_sy2sb;
     flexiblas_blasfn ssytrf;
-    flexiblas_blasfn ssytrf_aa;
-    flexiblas_blasfn ssytrf_aa_2stage;
-    flexiblas_blasfn ssytrf_rk;
     flexiblas_blasfn ssytrf_rook;
     flexiblas_blasfn ssytri;
     flexiblas_blasfn ssytri2;
     flexiblas_blasfn ssytri2x;
-    flexiblas_blasfn ssytri_3;
-    flexiblas_blasfn ssytri_3x;
     flexiblas_blasfn ssytri_rook;
     flexiblas_blasfn ssytrs;
     flexiblas_blasfn ssytrs2;
-    flexiblas_blasfn ssytrs_3;
-    flexiblas_blasfn ssytrs_aa;
-    flexiblas_blasfn ssytrs_aa_2stage;
     flexiblas_blasfn ssytrs_rook;
     flexiblas_blasfn stbcon;
     flexiblas_blasfn stbrfs;
@@ -1471,9 +1282,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn stgsy2;
     flexiblas_blasfn stgsyl;
     flexiblas_blasfn stpcon;
-    flexiblas_blasfn stplqt;
-    flexiblas_blasfn stplqt2;
-    flexiblas_blasfn stpmlqt;
     flexiblas_blasfn stpmqrt;
     flexiblas_blasfn stpqrt;
     flexiblas_blasfn stpqrt2;
@@ -1529,25 +1337,18 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgehd2;
     flexiblas_blasfn zgehrd;
     flexiblas_blasfn zgejsv;
-    flexiblas_blasfn zgelq;
     flexiblas_blasfn zgelq2;
     flexiblas_blasfn zgelqf;
-    flexiblas_blasfn zgelqt;
-    flexiblas_blasfn zgelqt3;
     flexiblas_blasfn zgels;
     flexiblas_blasfn zgelsd;
     flexiblas_blasfn zgelss;
     flexiblas_blasfn zgelsx;
     flexiblas_blasfn zgelsy;
-    flexiblas_blasfn zgemlq;
-    flexiblas_blasfn zgemlqt;
-    flexiblas_blasfn zgemqr;
     flexiblas_blasfn zgemqrt;
     flexiblas_blasfn zgeql2;
     flexiblas_blasfn zgeqlf;
     flexiblas_blasfn zgeqp3;
     flexiblas_blasfn zgeqpf;
-    flexiblas_blasfn zgeqr;
     flexiblas_blasfn zgeqr2;
     flexiblas_blasfn zgeqr2p;
     flexiblas_blasfn zgeqrf;
@@ -1562,7 +1363,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgesdd;
     flexiblas_blasfn zgesv;
     flexiblas_blasfn zgesvd;
-    flexiblas_blasfn zgesvdq;
     flexiblas_blasfn zgesvdx;
     flexiblas_blasfn zgesvj;
     flexiblas_blasfn zgesvx;
@@ -1572,8 +1372,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgetrf2;
     flexiblas_blasfn zgetri;
     flexiblas_blasfn zgetrs;
-    flexiblas_blasfn zgetsls;
-    flexiblas_blasfn zgetsqrhrt;
     flexiblas_blasfn zggbak;
     flexiblas_blasfn zggbal;
     flexiblas_blasfn zgges;
@@ -1601,68 +1399,43 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgttrf;
     flexiblas_blasfn zgttrs;
     flexiblas_blasfn zgtts2;
-    flexiblas_blasfn zhb2st_kernels;
     flexiblas_blasfn zhbev;
-    flexiblas_blasfn zhbev_2stage;
     flexiblas_blasfn zhbevd;
-    flexiblas_blasfn zhbevd_2stage;
     flexiblas_blasfn zhbevx;
-    flexiblas_blasfn zhbevx_2stage;
     flexiblas_blasfn zhbgst;
     flexiblas_blasfn zhbgv;
     flexiblas_blasfn zhbgvd;
     flexiblas_blasfn zhbgvx;
     flexiblas_blasfn zhbtrd;
     flexiblas_blasfn zhecon;
-    flexiblas_blasfn zhecon_3;
     flexiblas_blasfn zhecon_rook;
     flexiblas_blasfn zheequb;
     flexiblas_blasfn zheev;
-    flexiblas_blasfn zheev_2stage;
     flexiblas_blasfn zheevd;
-    flexiblas_blasfn zheevd_2stage;
     flexiblas_blasfn zheevr;
-    flexiblas_blasfn zheevr_2stage;
     flexiblas_blasfn zheevx;
-    flexiblas_blasfn zheevx_2stage;
     flexiblas_blasfn zhegs2;
     flexiblas_blasfn zhegst;
     flexiblas_blasfn zhegv;
-    flexiblas_blasfn zhegv_2stage;
     flexiblas_blasfn zhegvd;
     flexiblas_blasfn zhegvx;
     flexiblas_blasfn zherfs;
     flexiblas_blasfn zhesv;
-    flexiblas_blasfn zhesv_aa;
-    flexiblas_blasfn zhesv_aa_2stage;
-    flexiblas_blasfn zhesv_rk;
     flexiblas_blasfn zhesv_rook;
     flexiblas_blasfn zhesvx;
     flexiblas_blasfn zheswapr;
     flexiblas_blasfn zhetd2;
     flexiblas_blasfn zhetf2;
-    flexiblas_blasfn zhetf2_rk;
     flexiblas_blasfn zhetf2_rook;
     flexiblas_blasfn zhetrd;
-    flexiblas_blasfn zhetrd_2stage;
-    flexiblas_blasfn zhetrd_hb2st;
-    flexiblas_blasfn zhetrd_he2hb;
     flexiblas_blasfn zhetrf;
-    flexiblas_blasfn zhetrf_aa;
-    flexiblas_blasfn zhetrf_aa_2stage;
-    flexiblas_blasfn zhetrf_rk;
     flexiblas_blasfn zhetrf_rook;
     flexiblas_blasfn zhetri;
     flexiblas_blasfn zhetri2;
     flexiblas_blasfn zhetri2x;
-    flexiblas_blasfn zhetri_3;
-    flexiblas_blasfn zhetri_3x;
     flexiblas_blasfn zhetri_rook;
     flexiblas_blasfn zhetrs;
     flexiblas_blasfn zhetrs2;
-    flexiblas_blasfn zhetrs_3;
-    flexiblas_blasfn zhetrs_aa;
-    flexiblas_blasfn zhetrs_aa_2stage;
     flexiblas_blasfn zhetrs_rook;
     flexiblas_blasfn zhfrk;
     flexiblas_blasfn zhgeqz;
@@ -1702,8 +1475,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlags2;
     flexiblas_blasfn zlagtm;
     flexiblas_blasfn zlahef;
-    flexiblas_blasfn zlahef_aa;
-    flexiblas_blasfn zlahef_rk;
     flexiblas_blasfn zlahef_rook;
     flexiblas_blasfn zlahqr;
     flexiblas_blasfn zlahr2;
@@ -1712,8 +1483,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlals0;
     flexiblas_blasfn zlalsa;
     flexiblas_blasfn zlalsd;
-    flexiblas_blasfn zlamswlq;
-    flexiblas_blasfn zlamtsqr;
     flexiblas_blasfn zlangb;
     flexiblas_blasfn zlange;
     flexiblas_blasfn zlangt;
@@ -1748,21 +1517,15 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlaqsb;
     flexiblas_blasfn zlaqsp;
     flexiblas_blasfn zlaqsy;
-    flexiblas_blasfn zlaqz0;
-    flexiblas_blasfn zlaqz1;
-    flexiblas_blasfn zlaqz2;
-    flexiblas_blasfn zlaqz3;
     flexiblas_blasfn zlar1v;
     flexiblas_blasfn zlar2v;
     flexiblas_blasfn zlarcm;
     flexiblas_blasfn zlarf;
     flexiblas_blasfn zlarfb;
-    flexiblas_blasfn zlarfb_gett;
     flexiblas_blasfn zlarfg;
     flexiblas_blasfn zlarfgp;
     flexiblas_blasfn zlarft;
     flexiblas_blasfn zlarfx;
-    flexiblas_blasfn zlarfy;
     flexiblas_blasfn zlargv;
     flexiblas_blasfn zlarnv;
     flexiblas_blasfn zlarrv;
@@ -1775,11 +1538,8 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlaset;
     flexiblas_blasfn zlasr;
     flexiblas_blasfn zlassq;
-    flexiblas_blasfn zlaswlq;
     flexiblas_blasfn zlaswp;
     flexiblas_blasfn zlasyf;
-    flexiblas_blasfn zlasyf_aa;
-    flexiblas_blasfn zlasyf_rk;
     flexiblas_blasfn zlasyf_rook;
     flexiblas_blasfn zlat2c;
     flexiblas_blasfn zlatbs;
@@ -1788,10 +1548,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlatrd;
     flexiblas_blasfn zlatrs;
     flexiblas_blasfn zlatrz;
-    flexiblas_blasfn zlatsqr;
     flexiblas_blasfn zlatzm;
-    flexiblas_blasfn zlaunhr_col_getrfnp;
-    flexiblas_blasfn zlaunhr_col_getrfnp2;
     flexiblas_blasfn zlauu2;
     flexiblas_blasfn zlauum;
     flexiblas_blasfn zpbcon;
@@ -1851,41 +1608,26 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zstemr;
     flexiblas_blasfn zsteqr;
     flexiblas_blasfn zsycon;
-    flexiblas_blasfn zsycon_3;
     flexiblas_blasfn zsycon_rook;
     flexiblas_blasfn zsyconv;
-    flexiblas_blasfn zsyconvf;
-    flexiblas_blasfn zsyconvf_rook;
     flexiblas_blasfn zsyequb;
     flexiblas_blasfn zsymv;
     flexiblas_blasfn zsyr;
     flexiblas_blasfn zsyrfs;
     flexiblas_blasfn zsysv;
-    flexiblas_blasfn zsysv_aa;
-    flexiblas_blasfn zsysv_aa_2stage;
-    flexiblas_blasfn zsysv_rk;
     flexiblas_blasfn zsysv_rook;
     flexiblas_blasfn zsysvx;
     flexiblas_blasfn zsyswapr;
     flexiblas_blasfn zsytf2;
-    flexiblas_blasfn zsytf2_rk;
     flexiblas_blasfn zsytf2_rook;
     flexiblas_blasfn zsytrf;
-    flexiblas_blasfn zsytrf_aa;
-    flexiblas_blasfn zsytrf_aa_2stage;
-    flexiblas_blasfn zsytrf_rk;
     flexiblas_blasfn zsytrf_rook;
     flexiblas_blasfn zsytri;
     flexiblas_blasfn zsytri2;
     flexiblas_blasfn zsytri2x;
-    flexiblas_blasfn zsytri_3;
-    flexiblas_blasfn zsytri_3x;
     flexiblas_blasfn zsytri_rook;
     flexiblas_blasfn zsytrs;
     flexiblas_blasfn zsytrs2;
-    flexiblas_blasfn zsytrs_3;
-    flexiblas_blasfn zsytrs_aa;
-    flexiblas_blasfn zsytrs_aa_2stage;
     flexiblas_blasfn zsytrs_rook;
     flexiblas_blasfn ztbcon;
     flexiblas_blasfn ztbrfs;
@@ -1903,9 +1645,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ztgsy2;
     flexiblas_blasfn ztgsyl;
     flexiblas_blasfn ztpcon;
-    flexiblas_blasfn ztplqt;
-    flexiblas_blasfn ztplqt2;
-    flexiblas_blasfn ztpmlqt;
     flexiblas_blasfn ztpmqrt;
     flexiblas_blasfn ztpqrt;
     flexiblas_blasfn ztpqrt2;
@@ -1950,9 +1689,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zungr2;
     flexiblas_blasfn zungrq;
     flexiblas_blasfn zungtr;
-    flexiblas_blasfn zungtsqr;
-    flexiblas_blasfn zungtsqr_row;
-    flexiblas_blasfn zunhr_col;
     flexiblas_blasfn zunm22;
     flexiblas_blasfn zunm2l;
     flexiblas_blasfn zunm2r;
