@@ -25,8 +25,8 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 11
-#define FLEXIBLAS_LAPACK_PATCH 0
+#define FLEXIBLAS_LAPACK_MINOR 7
+#define FLEXIBLAS_LAPACK_PATCH 1
 #define FLEXIBLAS_LAPACK_EXTRA without deprecated
 
 
@@ -73,7 +73,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgels;
     flexiblas_blasfn cgelsd;
     flexiblas_blasfn cgelss;
-    flexiblas_blasfn cgelst;
     flexiblas_blasfn cgelsy;
     flexiblas_blasfn cgemlq;
     flexiblas_blasfn cgemlqt;
@@ -97,7 +96,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgesdd;
     flexiblas_blasfn cgesv;
     flexiblas_blasfn cgesvd;
-    flexiblas_blasfn cgesvdq;
     flexiblas_blasfn cgesvdx;
     flexiblas_blasfn cgesvj;
     flexiblas_blasfn cgesvx;
@@ -108,7 +106,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgetri;
     flexiblas_blasfn cgetrs;
     flexiblas_blasfn cgetsls;
-    flexiblas_blasfn cgetsqrhrt;
     flexiblas_blasfn cggbak;
     flexiblas_blasfn cggbal;
     flexiblas_blasfn cgges;
@@ -167,7 +164,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cherfs;
     flexiblas_blasfn chesv;
     flexiblas_blasfn chesv_aa;
-    flexiblas_blasfn chesv_aa_2stage;
     flexiblas_blasfn chesv_rk;
     flexiblas_blasfn chesv_rook;
     flexiblas_blasfn chesvx;
@@ -182,7 +178,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn chetrd_he2hb;
     flexiblas_blasfn chetrf;
     flexiblas_blasfn chetrf_aa;
-    flexiblas_blasfn chetrf_aa_2stage;
     flexiblas_blasfn chetrf_rk;
     flexiblas_blasfn chetrf_rook;
     flexiblas_blasfn chetri;
@@ -195,7 +190,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn chetrs2;
     flexiblas_blasfn chetrs_3;
     flexiblas_blasfn chetrs_aa;
-    flexiblas_blasfn chetrs_aa_2stage;
     flexiblas_blasfn chetrs_rook;
     flexiblas_blasfn chfrk;
     flexiblas_blasfn chgeqz;
@@ -281,16 +275,11 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn claqsb;
     flexiblas_blasfn claqsp;
     flexiblas_blasfn claqsy;
-    flexiblas_blasfn claqz0;
-    flexiblas_blasfn claqz1;
-    flexiblas_blasfn claqz2;
-    flexiblas_blasfn claqz3;
     flexiblas_blasfn clar1v;
     flexiblas_blasfn clar2v;
     flexiblas_blasfn clarcm;
     flexiblas_blasfn clarf;
     flexiblas_blasfn clarfb;
-    flexiblas_blasfn clarfb_gett;
     flexiblas_blasfn clarfg;
     flexiblas_blasfn clarfgp;
     flexiblas_blasfn clarft;
@@ -319,11 +308,8 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn clatps;
     flexiblas_blasfn clatrd;
     flexiblas_blasfn clatrs;
-    flexiblas_blasfn clatrs3;
     flexiblas_blasfn clatrz;
     flexiblas_blasfn clatsqr;
-    flexiblas_blasfn claunhr_col_getrfnp;
-    flexiblas_blasfn claunhr_col_getrfnp2;
     flexiblas_blasfn clauu2;
     flexiblas_blasfn clauum;
     flexiblas_blasfn cpbcon;
@@ -395,7 +381,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn csyrfs;
     flexiblas_blasfn csysv;
     flexiblas_blasfn csysv_aa;
-    flexiblas_blasfn csysv_aa_2stage;
     flexiblas_blasfn csysv_rk;
     flexiblas_blasfn csysv_rook;
     flexiblas_blasfn csysvx;
@@ -405,7 +390,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn csytf2_rook;
     flexiblas_blasfn csytrf;
     flexiblas_blasfn csytrf_aa;
-    flexiblas_blasfn csytrf_aa_2stage;
     flexiblas_blasfn csytrf_rk;
     flexiblas_blasfn csytrf_rook;
     flexiblas_blasfn csytri;
@@ -418,7 +402,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn csytrs2;
     flexiblas_blasfn csytrs_3;
     flexiblas_blasfn csytrs_aa;
-    flexiblas_blasfn csytrs_aa_2stage;
     flexiblas_blasfn csytrs_rook;
     flexiblas_blasfn ctbcon;
     flexiblas_blasfn ctbrfs;
@@ -456,7 +439,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ctrsen;
     flexiblas_blasfn ctrsna;
     flexiblas_blasfn ctrsyl;
-    flexiblas_blasfn ctrsyl3;
     flexiblas_blasfn ctrti2;
     flexiblas_blasfn ctrtri;
     flexiblas_blasfn ctrtrs;
@@ -483,9 +465,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cungr2;
     flexiblas_blasfn cungrq;
     flexiblas_blasfn cungtr;
-    flexiblas_blasfn cungtsqr;
-    flexiblas_blasfn cungtsqr_row;
-    flexiblas_blasfn cunhr_col;
     flexiblas_blasfn cunm22;
     flexiblas_blasfn cunm2l;
     flexiblas_blasfn cunm2r;
@@ -539,7 +518,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgels;
     flexiblas_blasfn dgelsd;
     flexiblas_blasfn dgelss;
-    flexiblas_blasfn dgelst;
     flexiblas_blasfn dgelsy;
     flexiblas_blasfn dgemlq;
     flexiblas_blasfn dgemlqt;
@@ -563,7 +541,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgesdd;
     flexiblas_blasfn dgesv;
     flexiblas_blasfn dgesvd;
-    flexiblas_blasfn dgesvdq;
     flexiblas_blasfn dgesvdx;
     flexiblas_blasfn dgesvj;
     flexiblas_blasfn dgesvx;
@@ -574,7 +551,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgetri;
     flexiblas_blasfn dgetrs;
     flexiblas_blasfn dgetsls;
-    flexiblas_blasfn dgetsqrhrt;
     flexiblas_blasfn dggbak;
     flexiblas_blasfn dggbal;
     flexiblas_blasfn dgges;
@@ -662,8 +638,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlantp;
     flexiblas_blasfn dlantr;
     flexiblas_blasfn dlanv2;
-    flexiblas_blasfn dlaorhr_col_getrfnp;
-    flexiblas_blasfn dlaorhr_col_getrfnp2;
     flexiblas_blasfn dlapll;
     flexiblas_blasfn dlapmr;
     flexiblas_blasfn dlapmt;
@@ -683,23 +657,16 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlaqsp;
     flexiblas_blasfn dlaqsy;
     flexiblas_blasfn dlaqtr;
-    flexiblas_blasfn dlaqz0;
-    flexiblas_blasfn dlaqz1;
-    flexiblas_blasfn dlaqz2;
-    flexiblas_blasfn dlaqz3;
-    flexiblas_blasfn dlaqz4;
     flexiblas_blasfn dlar1v;
     flexiblas_blasfn dlar2v;
     flexiblas_blasfn dlarf;
     flexiblas_blasfn dlarfb;
-    flexiblas_blasfn dlarfb_gett;
     flexiblas_blasfn dlarfg;
     flexiblas_blasfn dlarfgp;
     flexiblas_blasfn dlarft;
     flexiblas_blasfn dlarfx;
     flexiblas_blasfn dlarfy;
     flexiblas_blasfn dlargv;
-    flexiblas_blasfn dlarmm;
     flexiblas_blasfn dlarnv;
     flexiblas_blasfn dlarra;
     flexiblas_blasfn dlarrb;
@@ -757,7 +724,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlatps;
     flexiblas_blasfn dlatrd;
     flexiblas_blasfn dlatrs;
-    flexiblas_blasfn dlatrs3;
     flexiblas_blasfn dlatrz;
     flexiblas_blasfn dlatsqr;
     flexiblas_blasfn dlauu2;
@@ -784,9 +750,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dorgr2;
     flexiblas_blasfn dorgrq;
     flexiblas_blasfn dorgtr;
-    flexiblas_blasfn dorgtsqr;
-    flexiblas_blasfn dorgtsqr_row;
-    flexiblas_blasfn dorhr_col;
     flexiblas_blasfn dorm22;
     flexiblas_blasfn dorm2l;
     flexiblas_blasfn dorm2r;
@@ -842,7 +805,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dpttrf;
     flexiblas_blasfn dpttrs;
     flexiblas_blasfn dptts2;
-    flexiblas_blasfn droundup_lwork;
     flexiblas_blasfn drscl;
     flexiblas_blasfn dsb2st_kernels;
     flexiblas_blasfn dsbev;
@@ -910,7 +872,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dsyrfs;
     flexiblas_blasfn dsysv;
     flexiblas_blasfn dsysv_aa;
-    flexiblas_blasfn dsysv_aa_2stage;
     flexiblas_blasfn dsysv_rk;
     flexiblas_blasfn dsysv_rook;
     flexiblas_blasfn dsysvx;
@@ -925,7 +886,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dsytrd_sy2sb;
     flexiblas_blasfn dsytrf;
     flexiblas_blasfn dsytrf_aa;
-    flexiblas_blasfn dsytrf_aa_2stage;
     flexiblas_blasfn dsytrf_rk;
     flexiblas_blasfn dsytrf_rook;
     flexiblas_blasfn dsytri;
@@ -938,7 +898,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dsytrs2;
     flexiblas_blasfn dsytrs_3;
     flexiblas_blasfn dsytrs_aa;
-    flexiblas_blasfn dsytrs_aa_2stage;
     flexiblas_blasfn dsytrs_rook;
     flexiblas_blasfn dtbcon;
     flexiblas_blasfn dtbrfs;
@@ -976,7 +935,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dtrsen;
     flexiblas_blasfn dtrsna;
     flexiblas_blasfn dtrsyl;
-    flexiblas_blasfn dtrsyl3;
     flexiblas_blasfn dtrti2;
     flexiblas_blasfn dtrtri;
     flexiblas_blasfn dtrtrs;
@@ -992,7 +950,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn iladlc;
     flexiblas_blasfn iladlr;
     flexiblas_blasfn ilaenv;
-    flexiblas_blasfn ilaenv2stage;
     flexiblas_blasfn ilaprec;
     flexiblas_blasfn ilaslc;
     flexiblas_blasfn ilaslr;
@@ -1042,7 +999,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgels;
     flexiblas_blasfn sgelsd;
     flexiblas_blasfn sgelss;
-    flexiblas_blasfn sgelst;
     flexiblas_blasfn sgelsy;
     flexiblas_blasfn sgemlq;
     flexiblas_blasfn sgemlqt;
@@ -1066,7 +1022,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgesdd;
     flexiblas_blasfn sgesv;
     flexiblas_blasfn sgesvd;
-    flexiblas_blasfn sgesvdq;
     flexiblas_blasfn sgesvdx;
     flexiblas_blasfn sgesvj;
     flexiblas_blasfn sgesvx;
@@ -1077,7 +1032,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgetri;
     flexiblas_blasfn sgetrs;
     flexiblas_blasfn sgetsls;
-    flexiblas_blasfn sgetsqrhrt;
     flexiblas_blasfn sggbak;
     flexiblas_blasfn sggbal;
     flexiblas_blasfn sgges;
@@ -1165,8 +1119,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slantp;
     flexiblas_blasfn slantr;
     flexiblas_blasfn slanv2;
-    flexiblas_blasfn slaorhr_col_getrfnp;
-    flexiblas_blasfn slaorhr_col_getrfnp2;
     flexiblas_blasfn slapll;
     flexiblas_blasfn slapmr;
     flexiblas_blasfn slapmt;
@@ -1186,23 +1138,16 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slaqsp;
     flexiblas_blasfn slaqsy;
     flexiblas_blasfn slaqtr;
-    flexiblas_blasfn slaqz0;
-    flexiblas_blasfn slaqz1;
-    flexiblas_blasfn slaqz2;
-    flexiblas_blasfn slaqz3;
-    flexiblas_blasfn slaqz4;
     flexiblas_blasfn slar1v;
     flexiblas_blasfn slar2v;
     flexiblas_blasfn slarf;
     flexiblas_blasfn slarfb;
-    flexiblas_blasfn slarfb_gett;
     flexiblas_blasfn slarfg;
     flexiblas_blasfn slarfgp;
     flexiblas_blasfn slarft;
     flexiblas_blasfn slarfx;
     flexiblas_blasfn slarfy;
     flexiblas_blasfn slargv;
-    flexiblas_blasfn slarmm;
     flexiblas_blasfn slarnv;
     flexiblas_blasfn slarra;
     flexiblas_blasfn slarrb;
@@ -1259,7 +1204,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slatps;
     flexiblas_blasfn slatrd;
     flexiblas_blasfn slatrs;
-    flexiblas_blasfn slatrs3;
     flexiblas_blasfn slatrz;
     flexiblas_blasfn slatsqr;
     flexiblas_blasfn slauu2;
@@ -1286,9 +1230,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sorgr2;
     flexiblas_blasfn sorgrq;
     flexiblas_blasfn sorgtr;
-    flexiblas_blasfn sorgtsqr;
-    flexiblas_blasfn sorgtsqr_row;
-    flexiblas_blasfn sorhr_col;
     flexiblas_blasfn sorm22;
     flexiblas_blasfn sorm2l;
     flexiblas_blasfn sorm2r;
@@ -1344,7 +1285,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn spttrf;
     flexiblas_blasfn spttrs;
     flexiblas_blasfn sptts2;
-    flexiblas_blasfn sroundup_lwork;
     flexiblas_blasfn srscl;
     flexiblas_blasfn ssb2st_kernels;
     flexiblas_blasfn ssbev;
@@ -1409,7 +1349,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ssyrfs;
     flexiblas_blasfn ssysv;
     flexiblas_blasfn ssysv_aa;
-    flexiblas_blasfn ssysv_aa_2stage;
     flexiblas_blasfn ssysv_rk;
     flexiblas_blasfn ssysv_rook;
     flexiblas_blasfn ssysvx;
@@ -1424,7 +1363,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ssytrd_sy2sb;
     flexiblas_blasfn ssytrf;
     flexiblas_blasfn ssytrf_aa;
-    flexiblas_blasfn ssytrf_aa_2stage;
     flexiblas_blasfn ssytrf_rk;
     flexiblas_blasfn ssytrf_rook;
     flexiblas_blasfn ssytri;
@@ -1437,7 +1375,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ssytrs2;
     flexiblas_blasfn ssytrs_3;
     flexiblas_blasfn ssytrs_aa;
-    flexiblas_blasfn ssytrs_aa_2stage;
     flexiblas_blasfn ssytrs_rook;
     flexiblas_blasfn stbcon;
     flexiblas_blasfn stbrfs;
@@ -1475,7 +1412,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn strsen;
     flexiblas_blasfn strsna;
     flexiblas_blasfn strsyl;
-    flexiblas_blasfn strsyl3;
     flexiblas_blasfn strti2;
     flexiblas_blasfn strtri;
     flexiblas_blasfn strtrs;
@@ -1519,7 +1455,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgels;
     flexiblas_blasfn zgelsd;
     flexiblas_blasfn zgelss;
-    flexiblas_blasfn zgelst;
     flexiblas_blasfn zgelsy;
     flexiblas_blasfn zgemlq;
     flexiblas_blasfn zgemlqt;
@@ -1543,7 +1478,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgesdd;
     flexiblas_blasfn zgesv;
     flexiblas_blasfn zgesvd;
-    flexiblas_blasfn zgesvdq;
     flexiblas_blasfn zgesvdx;
     flexiblas_blasfn zgesvj;
     flexiblas_blasfn zgesvx;
@@ -1554,7 +1488,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgetri;
     flexiblas_blasfn zgetrs;
     flexiblas_blasfn zgetsls;
-    flexiblas_blasfn zgetsqrhrt;
     flexiblas_blasfn zggbak;
     flexiblas_blasfn zggbal;
     flexiblas_blasfn zgges;
@@ -1613,7 +1546,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zherfs;
     flexiblas_blasfn zhesv;
     flexiblas_blasfn zhesv_aa;
-    flexiblas_blasfn zhesv_aa_2stage;
     flexiblas_blasfn zhesv_rk;
     flexiblas_blasfn zhesv_rook;
     flexiblas_blasfn zhesvx;
@@ -1628,7 +1560,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zhetrd_he2hb;
     flexiblas_blasfn zhetrf;
     flexiblas_blasfn zhetrf_aa;
-    flexiblas_blasfn zhetrf_aa_2stage;
     flexiblas_blasfn zhetrf_rk;
     flexiblas_blasfn zhetrf_rook;
     flexiblas_blasfn zhetri;
@@ -1641,7 +1572,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zhetrs2;
     flexiblas_blasfn zhetrs_3;
     flexiblas_blasfn zhetrs_aa;
-    flexiblas_blasfn zhetrs_aa_2stage;
     flexiblas_blasfn zhetrs_rook;
     flexiblas_blasfn zhfrk;
     flexiblas_blasfn zhgeqz;
@@ -1726,16 +1656,11 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlaqsb;
     flexiblas_blasfn zlaqsp;
     flexiblas_blasfn zlaqsy;
-    flexiblas_blasfn zlaqz0;
-    flexiblas_blasfn zlaqz1;
-    flexiblas_blasfn zlaqz2;
-    flexiblas_blasfn zlaqz3;
     flexiblas_blasfn zlar1v;
     flexiblas_blasfn zlar2v;
     flexiblas_blasfn zlarcm;
     flexiblas_blasfn zlarf;
     flexiblas_blasfn zlarfb;
-    flexiblas_blasfn zlarfb_gett;
     flexiblas_blasfn zlarfg;
     flexiblas_blasfn zlarfgp;
     flexiblas_blasfn zlarft;
@@ -1765,11 +1690,8 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlatps;
     flexiblas_blasfn zlatrd;
     flexiblas_blasfn zlatrs;
-    flexiblas_blasfn zlatrs3;
     flexiblas_blasfn zlatrz;
     flexiblas_blasfn zlatsqr;
-    flexiblas_blasfn zlaunhr_col_getrfnp;
-    flexiblas_blasfn zlaunhr_col_getrfnp2;
     flexiblas_blasfn zlauu2;
     flexiblas_blasfn zlauum;
     flexiblas_blasfn zpbcon;
@@ -1840,7 +1762,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zsyrfs;
     flexiblas_blasfn zsysv;
     flexiblas_blasfn zsysv_aa;
-    flexiblas_blasfn zsysv_aa_2stage;
     flexiblas_blasfn zsysv_rk;
     flexiblas_blasfn zsysv_rook;
     flexiblas_blasfn zsysvx;
@@ -1850,7 +1771,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zsytf2_rook;
     flexiblas_blasfn zsytrf;
     flexiblas_blasfn zsytrf_aa;
-    flexiblas_blasfn zsytrf_aa_2stage;
     flexiblas_blasfn zsytrf_rk;
     flexiblas_blasfn zsytrf_rook;
     flexiblas_blasfn zsytri;
@@ -1863,7 +1783,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zsytrs2;
     flexiblas_blasfn zsytrs_3;
     flexiblas_blasfn zsytrs_aa;
-    flexiblas_blasfn zsytrs_aa_2stage;
     flexiblas_blasfn zsytrs_rook;
     flexiblas_blasfn ztbcon;
     flexiblas_blasfn ztbrfs;
@@ -1901,7 +1820,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ztrsen;
     flexiblas_blasfn ztrsna;
     flexiblas_blasfn ztrsyl;
-    flexiblas_blasfn ztrsyl3;
     flexiblas_blasfn ztrti2;
     flexiblas_blasfn ztrtri;
     flexiblas_blasfn ztrtrs;
@@ -1928,9 +1846,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zungr2;
     flexiblas_blasfn zungrq;
     flexiblas_blasfn zungtr;
-    flexiblas_blasfn zungtsqr;
-    flexiblas_blasfn zungtsqr_row;
-    flexiblas_blasfn zunhr_col;
     flexiblas_blasfn zunm22;
     flexiblas_blasfn zunm2l;
     flexiblas_blasfn zunm2r;
