@@ -25,8 +25,8 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 10
-#define FLEXIBLAS_LAPACK_PATCH 0
+#define FLEXIBLAS_LAPACK_MINOR 6
+#define FLEXIBLAS_LAPACK_PATCH 1
 
 
 #ifdef __cplusplus
@@ -84,10 +84,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgehrd_work;
     void *LAPACKE_cgejsv;
     void *LAPACKE_cgejsv_work;
-    void *LAPACKE_cgelq;
     void *LAPACKE_cgelq2;
     void *LAPACKE_cgelq2_work;
-    void *LAPACKE_cgelq_work;
     void *LAPACKE_cgelqf;
     void *LAPACKE_cgelqf_work;
     void *LAPACKE_cgels;
@@ -98,10 +96,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgelss_work;
     void *LAPACKE_cgelsy;
     void *LAPACKE_cgelsy_work;
-    void *LAPACKE_cgemlq;
-    void *LAPACKE_cgemlq_work;
-    void *LAPACKE_cgemqr;
-    void *LAPACKE_cgemqr_work;
     void *LAPACKE_cgemqrt;
     void *LAPACKE_cgemqrt_work;
     void *LAPACKE_cgeqlf;
@@ -110,10 +104,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgeqp3_work;
     void *LAPACKE_cgeqpf;
     void *LAPACKE_cgeqpf_work;
-    void *LAPACKE_cgeqr;
     void *LAPACKE_cgeqr2;
     void *LAPACKE_cgeqr2_work;
-    void *LAPACKE_cgeqr_work;
     void *LAPACKE_cgeqrf;
     void *LAPACKE_cgeqrf_work;
     void *LAPACKE_cgeqrfp;
@@ -134,8 +126,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgesv_work;
     void *LAPACKE_cgesvd;
     void *LAPACKE_cgesvd_work;
-    void *LAPACKE_cgesvdq;
-    void *LAPACKE_cgesvdq_work;
     void *LAPACKE_cgesvdx;
     void *LAPACKE_cgesvdx_work;
     void *LAPACKE_cgesvj;
@@ -152,10 +142,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgetri_work;
     void *LAPACKE_cgetrs;
     void *LAPACKE_cgetrs_work;
-    void *LAPACKE_cgetsls;
-    void *LAPACKE_cgetsls_work;
-    void *LAPACKE_cgetsqrhrt;
-    void *LAPACKE_cgetsqrhrt_work;
     void *LAPACKE_cggbak;
     void *LAPACKE_cggbak_work;
     void *LAPACKE_cggbal;
@@ -205,16 +191,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgttrs;
     void *LAPACKE_cgttrs_work;
     void *LAPACKE_chbev;
-    void *LAPACKE_chbev_2stage;
-    void *LAPACKE_chbev_2stage_work;
     void *LAPACKE_chbev_work;
     void *LAPACKE_chbevd;
-    void *LAPACKE_chbevd_2stage;
-    void *LAPACKE_chbevd_2stage_work;
     void *LAPACKE_chbevd_work;
     void *LAPACKE_chbevx;
-    void *LAPACKE_chbevx_2stage;
-    void *LAPACKE_chbevx_2stage_work;
     void *LAPACKE_chbevx_work;
     void *LAPACKE_chbgst;
     void *LAPACKE_chbgst_work;
@@ -227,32 +207,20 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_chbtrd;
     void *LAPACKE_chbtrd_work;
     void *LAPACKE_checon;
-    void *LAPACKE_checon_3;
-    void *LAPACKE_checon_3_work;
     void *LAPACKE_checon_work;
     void *LAPACKE_cheequb;
     void *LAPACKE_cheequb_work;
     void *LAPACKE_cheev;
-    void *LAPACKE_cheev_2stage;
-    void *LAPACKE_cheev_2stage_work;
     void *LAPACKE_cheev_work;
     void *LAPACKE_cheevd;
-    void *LAPACKE_cheevd_2stage;
-    void *LAPACKE_cheevd_2stage_work;
     void *LAPACKE_cheevd_work;
     void *LAPACKE_cheevr;
-    void *LAPACKE_cheevr_2stage;
-    void *LAPACKE_cheevr_2stage_work;
     void *LAPACKE_cheevr_work;
     void *LAPACKE_cheevx;
-    void *LAPACKE_cheevx_2stage;
-    void *LAPACKE_cheevx_2stage_work;
     void *LAPACKE_cheevx_work;
     void *LAPACKE_chegst;
     void *LAPACKE_chegst_work;
     void *LAPACKE_chegv;
-    void *LAPACKE_chegv_2stage;
-    void *LAPACKE_chegv_2stage_work;
     void *LAPACKE_chegv_work;
     void *LAPACKE_chegvd;
     void *LAPACKE_chegvd_work;
@@ -261,12 +229,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cherfs;
     void *LAPACKE_cherfs_work;
     void *LAPACKE_chesv;
-    void *LAPACKE_chesv_aa;
-    void *LAPACKE_chesv_aa_2stage;
-    void *LAPACKE_chesv_aa_2stage_work;
-    void *LAPACKE_chesv_aa_work;
-    void *LAPACKE_chesv_rk;
-    void *LAPACKE_chesv_rk_work;
     void *LAPACKE_chesv_work;
     void *LAPACKE_chesvx;
     void *LAPACKE_chesvx_work;
@@ -275,12 +237,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_chetrd;
     void *LAPACKE_chetrd_work;
     void *LAPACKE_chetrf;
-    void *LAPACKE_chetrf_aa;
-    void *LAPACKE_chetrf_aa_2stage;
-    void *LAPACKE_chetrf_aa_2stage_work;
-    void *LAPACKE_chetrf_aa_work;
-    void *LAPACKE_chetrf_rk;
-    void *LAPACKE_chetrf_rk_work;
     void *LAPACKE_chetrf_rook;
     void *LAPACKE_chetrf_rook_work;
     void *LAPACKE_chetrf_work;
@@ -289,18 +245,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_chetri2_work;
     void *LAPACKE_chetri2x;
     void *LAPACKE_chetri2x_work;
-    void *LAPACKE_chetri_3;
-    void *LAPACKE_chetri_3_work;
     void *LAPACKE_chetri_work;
     void *LAPACKE_chetrs;
     void *LAPACKE_chetrs2;
     void *LAPACKE_chetrs2_work;
-    void *LAPACKE_chetrs_3;
-    void *LAPACKE_chetrs_3_work;
-    void *LAPACKE_chetrs_aa;
-    void *LAPACKE_chetrs_aa_2stage;
-    void *LAPACKE_chetrs_aa_2stage_work;
-    void *LAPACKE_chetrs_aa_work;
     void *LAPACKE_chetrs_rook;
     void *LAPACKE_chetrs_rook_work;
     void *LAPACKE_chetrs_work;
@@ -350,8 +298,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_clacp2_work;
     void *LAPACKE_clacpy;
     void *LAPACKE_clacpy_work;
-    void *LAPACKE_clacrm;
-    void *LAPACKE_clacrm_work;
     void *LAPACKE_clag2z;
     void *LAPACKE_clag2z_work;
     void *LAPACKE_clange;
@@ -366,8 +312,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_clapmr_work;
     void *LAPACKE_clapmt;
     void *LAPACKE_clapmt_work;
-    void *LAPACKE_clarcm;
-    void *LAPACKE_clarcm_work;
     void *LAPACKE_clarfb;
     void *LAPACKE_clarfb_work;
     void *LAPACKE_clarfg;
@@ -382,8 +326,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_clascl_work;
     void *LAPACKE_claset;
     void *LAPACKE_claset_work;
-    void *LAPACKE_classq;
-    void *LAPACKE_classq_work;
     void *LAPACKE_claswp;
     void *LAPACKE_claswp_work;
     void *LAPACKE_clauum;
@@ -487,8 +429,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_csteqr;
     void *LAPACKE_csteqr_work;
     void *LAPACKE_csycon;
-    void *LAPACKE_csycon_3;
-    void *LAPACKE_csycon_3_work;
     void *LAPACKE_csycon_work;
     void *LAPACKE_csyconv;
     void *LAPACKE_csyconv_work;
@@ -499,12 +439,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_csyrfs;
     void *LAPACKE_csyrfs_work;
     void *LAPACKE_csysv;
-    void *LAPACKE_csysv_aa;
-    void *LAPACKE_csysv_aa_2stage;
-    void *LAPACKE_csysv_aa_2stage_work;
-    void *LAPACKE_csysv_aa_work;
-    void *LAPACKE_csysv_rk;
-    void *LAPACKE_csysv_rk_work;
     void *LAPACKE_csysv_rook;
     void *LAPACKE_csysv_rook_work;
     void *LAPACKE_csysv_work;
@@ -513,12 +447,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_csyswapr;
     void *LAPACKE_csyswapr_work;
     void *LAPACKE_csytrf;
-    void *LAPACKE_csytrf_aa;
-    void *LAPACKE_csytrf_aa_2stage;
-    void *LAPACKE_csytrf_aa_2stage_work;
-    void *LAPACKE_csytrf_aa_work;
-    void *LAPACKE_csytrf_rk;
-    void *LAPACKE_csytrf_rk_work;
     void *LAPACKE_csytrf_rook;
     void *LAPACKE_csytrf_rook_work;
     void *LAPACKE_csytrf_work;
@@ -527,18 +455,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_csytri2_work;
     void *LAPACKE_csytri2x;
     void *LAPACKE_csytri2x_work;
-    void *LAPACKE_csytri_3;
-    void *LAPACKE_csytri_3_work;
     void *LAPACKE_csytri_work;
     void *LAPACKE_csytrs;
     void *LAPACKE_csytrs2;
     void *LAPACKE_csytrs2_work;
-    void *LAPACKE_csytrs_3;
-    void *LAPACKE_csytrs_3_work;
-    void *LAPACKE_csytrs_aa;
-    void *LAPACKE_csytrs_aa_2stage;
-    void *LAPACKE_csytrs_aa_2stage_work;
-    void *LAPACKE_csytrs_aa_work;
     void *LAPACKE_csytrs_rook;
     void *LAPACKE_csytrs_rook_work;
     void *LAPACKE_csytrs_work;
@@ -632,8 +552,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cungrq_work;
     void *LAPACKE_cungtr;
     void *LAPACKE_cungtr_work;
-    void *LAPACKE_cungtsqr_row;
-    void *LAPACKE_cungtsqr_row_work;
     void *LAPACKE_cunmbr;
     void *LAPACKE_cunmbr_work;
     void *LAPACKE_cunmhr;
@@ -706,10 +624,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgehrd_work;
     void *LAPACKE_dgejsv;
     void *LAPACKE_dgejsv_work;
-    void *LAPACKE_dgelq;
     void *LAPACKE_dgelq2;
     void *LAPACKE_dgelq2_work;
-    void *LAPACKE_dgelq_work;
     void *LAPACKE_dgelqf;
     void *LAPACKE_dgelqf_work;
     void *LAPACKE_dgels;
@@ -720,10 +636,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgelss_work;
     void *LAPACKE_dgelsy;
     void *LAPACKE_dgelsy_work;
-    void *LAPACKE_dgemlq;
-    void *LAPACKE_dgemlq_work;
-    void *LAPACKE_dgemqr;
-    void *LAPACKE_dgemqr_work;
     void *LAPACKE_dgemqrt;
     void *LAPACKE_dgemqrt_work;
     void *LAPACKE_dgeqlf;
@@ -732,10 +644,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgeqp3_work;
     void *LAPACKE_dgeqpf;
     void *LAPACKE_dgeqpf_work;
-    void *LAPACKE_dgeqr;
     void *LAPACKE_dgeqr2;
     void *LAPACKE_dgeqr2_work;
-    void *LAPACKE_dgeqr_work;
     void *LAPACKE_dgeqrf;
     void *LAPACKE_dgeqrf_work;
     void *LAPACKE_dgeqrfp;
@@ -756,8 +666,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgesv_work;
     void *LAPACKE_dgesvd;
     void *LAPACKE_dgesvd_work;
-    void *LAPACKE_dgesvdq;
-    void *LAPACKE_dgesvdq_work;
     void *LAPACKE_dgesvdx;
     void *LAPACKE_dgesvdx_work;
     void *LAPACKE_dgesvj;
@@ -774,10 +682,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgetri_work;
     void *LAPACKE_dgetrs;
     void *LAPACKE_dgetrs_work;
-    void *LAPACKE_dgetsls;
-    void *LAPACKE_dgetsls_work;
-    void *LAPACKE_dgetsqrhrt;
-    void *LAPACKE_dgetsqrhrt_work;
     void *LAPACKE_dggbak;
     void *LAPACKE_dggbak_work;
     void *LAPACKE_dggbal;
@@ -874,8 +778,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dlaset_work;
     void *LAPACKE_dlasrt;
     void *LAPACKE_dlasrt_work;
-    void *LAPACKE_dlassq;
-    void *LAPACKE_dlassq_work;
     void *LAPACKE_dlaswp;
     void *LAPACKE_dlaswp_work;
     void *LAPACKE_dlauum;
@@ -904,8 +806,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dorgrq_work;
     void *LAPACKE_dorgtr;
     void *LAPACKE_dorgtr_work;
-    void *LAPACKE_dorgtsqr_row;
-    void *LAPACKE_dorgtsqr_row_work;
     void *LAPACKE_dormbr;
     void *LAPACKE_dormbr_work;
     void *LAPACKE_dormhr;
@@ -997,16 +897,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dpttrs;
     void *LAPACKE_dpttrs_work;
     void *LAPACKE_dsbev;
-    void *LAPACKE_dsbev_2stage;
-    void *LAPACKE_dsbev_2stage_work;
     void *LAPACKE_dsbev_work;
     void *LAPACKE_dsbevd;
-    void *LAPACKE_dsbevd_2stage;
-    void *LAPACKE_dsbevd_2stage_work;
     void *LAPACKE_dsbevd_work;
     void *LAPACKE_dsbevx;
-    void *LAPACKE_dsbevx_2stage;
-    void *LAPACKE_dsbevx_2stage_work;
     void *LAPACKE_dsbevx_work;
     void *LAPACKE_dsbgst;
     void *LAPACKE_dsbgst_work;
@@ -1077,34 +971,22 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dstevx;
     void *LAPACKE_dstevx_work;
     void *LAPACKE_dsycon;
-    void *LAPACKE_dsycon_3;
-    void *LAPACKE_dsycon_3_work;
     void *LAPACKE_dsycon_work;
     void *LAPACKE_dsyconv;
     void *LAPACKE_dsyconv_work;
     void *LAPACKE_dsyequb;
     void *LAPACKE_dsyequb_work;
     void *LAPACKE_dsyev;
-    void *LAPACKE_dsyev_2stage;
-    void *LAPACKE_dsyev_2stage_work;
     void *LAPACKE_dsyev_work;
     void *LAPACKE_dsyevd;
-    void *LAPACKE_dsyevd_2stage;
-    void *LAPACKE_dsyevd_2stage_work;
     void *LAPACKE_dsyevd_work;
     void *LAPACKE_dsyevr;
-    void *LAPACKE_dsyevr_2stage;
-    void *LAPACKE_dsyevr_2stage_work;
     void *LAPACKE_dsyevr_work;
     void *LAPACKE_dsyevx;
-    void *LAPACKE_dsyevx_2stage;
-    void *LAPACKE_dsyevx_2stage_work;
     void *LAPACKE_dsyevx_work;
     void *LAPACKE_dsygst;
     void *LAPACKE_dsygst_work;
     void *LAPACKE_dsygv;
-    void *LAPACKE_dsygv_2stage;
-    void *LAPACKE_dsygv_2stage_work;
     void *LAPACKE_dsygv_work;
     void *LAPACKE_dsygvd;
     void *LAPACKE_dsygvd_work;
@@ -1113,12 +995,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dsyrfs;
     void *LAPACKE_dsyrfs_work;
     void *LAPACKE_dsysv;
-    void *LAPACKE_dsysv_aa;
-    void *LAPACKE_dsysv_aa_2stage;
-    void *LAPACKE_dsysv_aa_2stage_work;
-    void *LAPACKE_dsysv_aa_work;
-    void *LAPACKE_dsysv_rk;
-    void *LAPACKE_dsysv_rk_work;
     void *LAPACKE_dsysv_rook;
     void *LAPACKE_dsysv_rook_work;
     void *LAPACKE_dsysv_work;
@@ -1129,12 +1005,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dsytrd;
     void *LAPACKE_dsytrd_work;
     void *LAPACKE_dsytrf;
-    void *LAPACKE_dsytrf_aa;
-    void *LAPACKE_dsytrf_aa_2stage;
-    void *LAPACKE_dsytrf_aa_2stage_work;
-    void *LAPACKE_dsytrf_aa_work;
-    void *LAPACKE_dsytrf_rk;
-    void *LAPACKE_dsytrf_rk_work;
     void *LAPACKE_dsytrf_rook;
     void *LAPACKE_dsytrf_rook_work;
     void *LAPACKE_dsytrf_work;
@@ -1143,18 +1013,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dsytri2_work;
     void *LAPACKE_dsytri2x;
     void *LAPACKE_dsytri2x_work;
-    void *LAPACKE_dsytri_3;
-    void *LAPACKE_dsytri_3_work;
     void *LAPACKE_dsytri_work;
     void *LAPACKE_dsytrs;
     void *LAPACKE_dsytrs2;
     void *LAPACKE_dsytrs2_work;
-    void *LAPACKE_dsytrs_3;
-    void *LAPACKE_dsytrs_3_work;
-    void *LAPACKE_dsytrs_aa;
-    void *LAPACKE_dsytrs_aa_2stage;
-    void *LAPACKE_dsytrs_aa_2stage_work;
-    void *LAPACKE_dsytrs_aa_work;
     void *LAPACKE_dsytrs_rook;
     void *LAPACKE_dsytrs_rook_work;
     void *LAPACKE_dsytrs_work;
@@ -1228,7 +1090,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dtrttp_work;
     void *LAPACKE_dtzrzf;
     void *LAPACKE_dtzrzf_work;
-    void *LAPACKE_get_nancheck;
     void *LAPACKE_ilaver;
     void *LAPACKE_sbbcsd;
     void *LAPACKE_sbbcsd_work;
@@ -1240,7 +1101,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sbdsvdx_work;
     void *LAPACKE_sdisna;
     void *LAPACKE_sdisna_work;
-    void *LAPACKE_set_nancheck;
     void *LAPACKE_sgbbrd;
     void *LAPACKE_sgbbrd_work;
     void *LAPACKE_sgbcon;
@@ -1283,10 +1143,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgehrd_work;
     void *LAPACKE_sgejsv;
     void *LAPACKE_sgejsv_work;
-    void *LAPACKE_sgelq;
     void *LAPACKE_sgelq2;
     void *LAPACKE_sgelq2_work;
-    void *LAPACKE_sgelq_work;
     void *LAPACKE_sgelqf;
     void *LAPACKE_sgelqf_work;
     void *LAPACKE_sgels;
@@ -1297,10 +1155,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgelss_work;
     void *LAPACKE_sgelsy;
     void *LAPACKE_sgelsy_work;
-    void *LAPACKE_sgemlq;
-    void *LAPACKE_sgemlq_work;
-    void *LAPACKE_sgemqr;
-    void *LAPACKE_sgemqr_work;
     void *LAPACKE_sgemqrt;
     void *LAPACKE_sgemqrt_work;
     void *LAPACKE_sgeqlf;
@@ -1309,10 +1163,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgeqp3_work;
     void *LAPACKE_sgeqpf;
     void *LAPACKE_sgeqpf_work;
-    void *LAPACKE_sgeqr;
     void *LAPACKE_sgeqr2;
     void *LAPACKE_sgeqr2_work;
-    void *LAPACKE_sgeqr_work;
     void *LAPACKE_sgeqrf;
     void *LAPACKE_sgeqrf_work;
     void *LAPACKE_sgeqrfp;
@@ -1333,8 +1185,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgesv_work;
     void *LAPACKE_sgesvd;
     void *LAPACKE_sgesvd_work;
-    void *LAPACKE_sgesvdq;
-    void *LAPACKE_sgesvdq_work;
     void *LAPACKE_sgesvdx;
     void *LAPACKE_sgesvdx_work;
     void *LAPACKE_sgesvj;
@@ -1351,10 +1201,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgetri_work;
     void *LAPACKE_sgetrs;
     void *LAPACKE_sgetrs_work;
-    void *LAPACKE_sgetsls;
-    void *LAPACKE_sgetsls_work;
-    void *LAPACKE_sgetsqrhrt;
-    void *LAPACKE_sgetsqrhrt_work;
     void *LAPACKE_sggbak;
     void *LAPACKE_sggbak_work;
     void *LAPACKE_sggbal;
@@ -1451,8 +1297,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_slaset_work;
     void *LAPACKE_slasrt;
     void *LAPACKE_slasrt_work;
-    void *LAPACKE_slassq;
-    void *LAPACKE_slassq_work;
     void *LAPACKE_slaswp;
     void *LAPACKE_slaswp_work;
     void *LAPACKE_slauum;
@@ -1481,8 +1325,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sorgrq_work;
     void *LAPACKE_sorgtr;
     void *LAPACKE_sorgtr_work;
-    void *LAPACKE_sorgtsqr_row;
-    void *LAPACKE_sorgtsqr_row_work;
     void *LAPACKE_sormbr;
     void *LAPACKE_sormbr_work;
     void *LAPACKE_sormhr;
@@ -1574,16 +1416,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_spttrs;
     void *LAPACKE_spttrs_work;
     void *LAPACKE_ssbev;
-    void *LAPACKE_ssbev_2stage;
-    void *LAPACKE_ssbev_2stage_work;
     void *LAPACKE_ssbev_work;
     void *LAPACKE_ssbevd;
-    void *LAPACKE_ssbevd_2stage;
-    void *LAPACKE_ssbevd_2stage_work;
     void *LAPACKE_ssbevd_work;
     void *LAPACKE_ssbevx;
-    void *LAPACKE_ssbevx_2stage;
-    void *LAPACKE_ssbevx_2stage_work;
     void *LAPACKE_ssbevx_work;
     void *LAPACKE_ssbgst;
     void *LAPACKE_ssbgst_work;
@@ -1650,34 +1486,22 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sstevx;
     void *LAPACKE_sstevx_work;
     void *LAPACKE_ssycon;
-    void *LAPACKE_ssycon_3;
-    void *LAPACKE_ssycon_3_work;
     void *LAPACKE_ssycon_work;
     void *LAPACKE_ssyconv;
     void *LAPACKE_ssyconv_work;
     void *LAPACKE_ssyequb;
     void *LAPACKE_ssyequb_work;
     void *LAPACKE_ssyev;
-    void *LAPACKE_ssyev_2stage;
-    void *LAPACKE_ssyev_2stage_work;
     void *LAPACKE_ssyev_work;
     void *LAPACKE_ssyevd;
-    void *LAPACKE_ssyevd_2stage;
-    void *LAPACKE_ssyevd_2stage_work;
     void *LAPACKE_ssyevd_work;
     void *LAPACKE_ssyevr;
-    void *LAPACKE_ssyevr_2stage;
-    void *LAPACKE_ssyevr_2stage_work;
     void *LAPACKE_ssyevr_work;
     void *LAPACKE_ssyevx;
-    void *LAPACKE_ssyevx_2stage;
-    void *LAPACKE_ssyevx_2stage_work;
     void *LAPACKE_ssyevx_work;
     void *LAPACKE_ssygst;
     void *LAPACKE_ssygst_work;
     void *LAPACKE_ssygv;
-    void *LAPACKE_ssygv_2stage;
-    void *LAPACKE_ssygv_2stage_work;
     void *LAPACKE_ssygv_work;
     void *LAPACKE_ssygvd;
     void *LAPACKE_ssygvd_work;
@@ -1686,12 +1510,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ssyrfs;
     void *LAPACKE_ssyrfs_work;
     void *LAPACKE_ssysv;
-    void *LAPACKE_ssysv_aa;
-    void *LAPACKE_ssysv_aa_2stage;
-    void *LAPACKE_ssysv_aa_2stage_work;
-    void *LAPACKE_ssysv_aa_work;
-    void *LAPACKE_ssysv_rk;
-    void *LAPACKE_ssysv_rk_work;
     void *LAPACKE_ssysv_rook;
     void *LAPACKE_ssysv_rook_work;
     void *LAPACKE_ssysv_work;
@@ -1702,12 +1520,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ssytrd;
     void *LAPACKE_ssytrd_work;
     void *LAPACKE_ssytrf;
-    void *LAPACKE_ssytrf_aa;
-    void *LAPACKE_ssytrf_aa_2stage;
-    void *LAPACKE_ssytrf_aa_2stage_work;
-    void *LAPACKE_ssytrf_aa_work;
-    void *LAPACKE_ssytrf_rk;
-    void *LAPACKE_ssytrf_rk_work;
     void *LAPACKE_ssytrf_rook;
     void *LAPACKE_ssytrf_rook_work;
     void *LAPACKE_ssytrf_work;
@@ -1716,18 +1528,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ssytri2_work;
     void *LAPACKE_ssytri2x;
     void *LAPACKE_ssytri2x_work;
-    void *LAPACKE_ssytri_3;
-    void *LAPACKE_ssytri_3_work;
     void *LAPACKE_ssytri_work;
     void *LAPACKE_ssytrs;
     void *LAPACKE_ssytrs2;
     void *LAPACKE_ssytrs2_work;
-    void *LAPACKE_ssytrs_3;
-    void *LAPACKE_ssytrs_3_work;
-    void *LAPACKE_ssytrs_aa;
-    void *LAPACKE_ssytrs_aa_2stage;
-    void *LAPACKE_ssytrs_aa_2stage_work;
-    void *LAPACKE_ssytrs_aa_work;
     void *LAPACKE_ssytrs_rook;
     void *LAPACKE_ssytrs_rook_work;
     void *LAPACKE_ssytrs_work;
@@ -1851,10 +1655,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgehrd_work;
     void *LAPACKE_zgejsv;
     void *LAPACKE_zgejsv_work;
-    void *LAPACKE_zgelq;
     void *LAPACKE_zgelq2;
     void *LAPACKE_zgelq2_work;
-    void *LAPACKE_zgelq_work;
     void *LAPACKE_zgelqf;
     void *LAPACKE_zgelqf_work;
     void *LAPACKE_zgels;
@@ -1865,10 +1667,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgelss_work;
     void *LAPACKE_zgelsy;
     void *LAPACKE_zgelsy_work;
-    void *LAPACKE_zgemlq;
-    void *LAPACKE_zgemlq_work;
-    void *LAPACKE_zgemqr;
-    void *LAPACKE_zgemqr_work;
     void *LAPACKE_zgemqrt;
     void *LAPACKE_zgemqrt_work;
     void *LAPACKE_zgeqlf;
@@ -1877,10 +1675,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgeqp3_work;
     void *LAPACKE_zgeqpf;
     void *LAPACKE_zgeqpf_work;
-    void *LAPACKE_zgeqr;
     void *LAPACKE_zgeqr2;
     void *LAPACKE_zgeqr2_work;
-    void *LAPACKE_zgeqr_work;
     void *LAPACKE_zgeqrf;
     void *LAPACKE_zgeqrf_work;
     void *LAPACKE_zgeqrfp;
@@ -1901,8 +1697,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgesv_work;
     void *LAPACKE_zgesvd;
     void *LAPACKE_zgesvd_work;
-    void *LAPACKE_zgesvdq;
-    void *LAPACKE_zgesvdq_work;
     void *LAPACKE_zgesvdx;
     void *LAPACKE_zgesvdx_work;
     void *LAPACKE_zgesvj;
@@ -1919,10 +1713,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgetri_work;
     void *LAPACKE_zgetrs;
     void *LAPACKE_zgetrs_work;
-    void *LAPACKE_zgetsls;
-    void *LAPACKE_zgetsls_work;
-    void *LAPACKE_zgetsqrhrt;
-    void *LAPACKE_zgetsqrhrt_work;
     void *LAPACKE_zggbak;
     void *LAPACKE_zggbak_work;
     void *LAPACKE_zggbal;
@@ -1972,16 +1762,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgttrs;
     void *LAPACKE_zgttrs_work;
     void *LAPACKE_zhbev;
-    void *LAPACKE_zhbev_2stage;
-    void *LAPACKE_zhbev_2stage_work;
     void *LAPACKE_zhbev_work;
     void *LAPACKE_zhbevd;
-    void *LAPACKE_zhbevd_2stage;
-    void *LAPACKE_zhbevd_2stage_work;
     void *LAPACKE_zhbevd_work;
     void *LAPACKE_zhbevx;
-    void *LAPACKE_zhbevx_2stage;
-    void *LAPACKE_zhbevx_2stage_work;
     void *LAPACKE_zhbevx_work;
     void *LAPACKE_zhbgst;
     void *LAPACKE_zhbgst_work;
@@ -1994,32 +1778,20 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zhbtrd;
     void *LAPACKE_zhbtrd_work;
     void *LAPACKE_zhecon;
-    void *LAPACKE_zhecon_3;
-    void *LAPACKE_zhecon_3_work;
     void *LAPACKE_zhecon_work;
     void *LAPACKE_zheequb;
     void *LAPACKE_zheequb_work;
     void *LAPACKE_zheev;
-    void *LAPACKE_zheev_2stage;
-    void *LAPACKE_zheev_2stage_work;
     void *LAPACKE_zheev_work;
     void *LAPACKE_zheevd;
-    void *LAPACKE_zheevd_2stage;
-    void *LAPACKE_zheevd_2stage_work;
     void *LAPACKE_zheevd_work;
     void *LAPACKE_zheevr;
-    void *LAPACKE_zheevr_2stage;
-    void *LAPACKE_zheevr_2stage_work;
     void *LAPACKE_zheevr_work;
     void *LAPACKE_zheevx;
-    void *LAPACKE_zheevx_2stage;
-    void *LAPACKE_zheevx_2stage_work;
     void *LAPACKE_zheevx_work;
     void *LAPACKE_zhegst;
     void *LAPACKE_zhegst_work;
     void *LAPACKE_zhegv;
-    void *LAPACKE_zhegv_2stage;
-    void *LAPACKE_zhegv_2stage_work;
     void *LAPACKE_zhegv_work;
     void *LAPACKE_zhegvd;
     void *LAPACKE_zhegvd_work;
@@ -2028,12 +1800,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zherfs;
     void *LAPACKE_zherfs_work;
     void *LAPACKE_zhesv;
-    void *LAPACKE_zhesv_aa;
-    void *LAPACKE_zhesv_aa_2stage;
-    void *LAPACKE_zhesv_aa_2stage_work;
-    void *LAPACKE_zhesv_aa_work;
-    void *LAPACKE_zhesv_rk;
-    void *LAPACKE_zhesv_rk_work;
     void *LAPACKE_zhesv_work;
     void *LAPACKE_zhesvx;
     void *LAPACKE_zhesvx_work;
@@ -2042,12 +1808,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zhetrd;
     void *LAPACKE_zhetrd_work;
     void *LAPACKE_zhetrf;
-    void *LAPACKE_zhetrf_aa;
-    void *LAPACKE_zhetrf_aa_2stage;
-    void *LAPACKE_zhetrf_aa_2stage_work;
-    void *LAPACKE_zhetrf_aa_work;
-    void *LAPACKE_zhetrf_rk;
-    void *LAPACKE_zhetrf_rk_work;
     void *LAPACKE_zhetrf_rook;
     void *LAPACKE_zhetrf_rook_work;
     void *LAPACKE_zhetrf_work;
@@ -2056,18 +1816,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zhetri2_work;
     void *LAPACKE_zhetri2x;
     void *LAPACKE_zhetri2x_work;
-    void *LAPACKE_zhetri_3;
-    void *LAPACKE_zhetri_3_work;
     void *LAPACKE_zhetri_work;
     void *LAPACKE_zhetrs;
     void *LAPACKE_zhetrs2;
     void *LAPACKE_zhetrs2_work;
-    void *LAPACKE_zhetrs_3;
-    void *LAPACKE_zhetrs_3_work;
-    void *LAPACKE_zhetrs_aa;
-    void *LAPACKE_zhetrs_aa_2stage;
-    void *LAPACKE_zhetrs_aa_2stage_work;
-    void *LAPACKE_zhetrs_aa_work;
     void *LAPACKE_zhetrs_rook;
     void *LAPACKE_zhetrs_rook_work;
     void *LAPACKE_zhetrs_work;
@@ -2117,8 +1869,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zlacp2_work;
     void *LAPACKE_zlacpy;
     void *LAPACKE_zlacpy_work;
-    void *LAPACKE_zlacrm;
-    void *LAPACKE_zlacrm_work;
     void *LAPACKE_zlag2c;
     void *LAPACKE_zlag2c_work;
     void *LAPACKE_zlange;
@@ -2133,8 +1883,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zlapmr_work;
     void *LAPACKE_zlapmt;
     void *LAPACKE_zlapmt_work;
-    void *LAPACKE_zlarcm;
-    void *LAPACKE_zlarcm_work;
     void *LAPACKE_zlarfb;
     void *LAPACKE_zlarfb_work;
     void *LAPACKE_zlarfg;
@@ -2149,8 +1897,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zlascl_work;
     void *LAPACKE_zlaset;
     void *LAPACKE_zlaset_work;
-    void *LAPACKE_zlassq;
-    void *LAPACKE_zlassq_work;
     void *LAPACKE_zlaswp;
     void *LAPACKE_zlaswp_work;
     void *LAPACKE_zlauum;
@@ -2254,8 +2000,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zsteqr;
     void *LAPACKE_zsteqr_work;
     void *LAPACKE_zsycon;
-    void *LAPACKE_zsycon_3;
-    void *LAPACKE_zsycon_3_work;
     void *LAPACKE_zsycon_work;
     void *LAPACKE_zsyconv;
     void *LAPACKE_zsyconv_work;
@@ -2266,12 +2010,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zsyrfs;
     void *LAPACKE_zsyrfs_work;
     void *LAPACKE_zsysv;
-    void *LAPACKE_zsysv_aa;
-    void *LAPACKE_zsysv_aa_2stage;
-    void *LAPACKE_zsysv_aa_2stage_work;
-    void *LAPACKE_zsysv_aa_work;
-    void *LAPACKE_zsysv_rk;
-    void *LAPACKE_zsysv_rk_work;
     void *LAPACKE_zsysv_rook;
     void *LAPACKE_zsysv_rook_work;
     void *LAPACKE_zsysv_work;
@@ -2280,12 +2018,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zsyswapr;
     void *LAPACKE_zsyswapr_work;
     void *LAPACKE_zsytrf;
-    void *LAPACKE_zsytrf_aa;
-    void *LAPACKE_zsytrf_aa_2stage;
-    void *LAPACKE_zsytrf_aa_2stage_work;
-    void *LAPACKE_zsytrf_aa_work;
-    void *LAPACKE_zsytrf_rk;
-    void *LAPACKE_zsytrf_rk_work;
     void *LAPACKE_zsytrf_rook;
     void *LAPACKE_zsytrf_rook_work;
     void *LAPACKE_zsytrf_work;
@@ -2294,18 +2026,10 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zsytri2_work;
     void *LAPACKE_zsytri2x;
     void *LAPACKE_zsytri2x_work;
-    void *LAPACKE_zsytri_3;
-    void *LAPACKE_zsytri_3_work;
     void *LAPACKE_zsytri_work;
     void *LAPACKE_zsytrs;
     void *LAPACKE_zsytrs2;
     void *LAPACKE_zsytrs2_work;
-    void *LAPACKE_zsytrs_3;
-    void *LAPACKE_zsytrs_3_work;
-    void *LAPACKE_zsytrs_aa;
-    void *LAPACKE_zsytrs_aa_2stage;
-    void *LAPACKE_zsytrs_aa_2stage_work;
-    void *LAPACKE_zsytrs_aa_work;
     void *LAPACKE_zsytrs_rook;
     void *LAPACKE_zsytrs_rook_work;
     void *LAPACKE_zsytrs_work;
@@ -2399,8 +2123,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zungrq_work;
     void *LAPACKE_zungtr;
     void *LAPACKE_zungtr_work;
-    void *LAPACKE_zungtsqr_row;
-    void *LAPACKE_zungtsqr_row_work;
     void *LAPACKE_zunmbr;
     void *LAPACKE_zunmbr_work;
     void *LAPACKE_zunmhr;
