@@ -25,8 +25,8 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 11
-#define FLEXIBLAS_LAPACK_PATCH 0
+#define FLEXIBLAS_LAPACK_MINOR 9
+#define FLEXIBLAS_LAPACK_PATCH 1
 
 
 #ifdef __cplusplus
@@ -354,8 +354,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_clacrm_work;
     void *LAPACKE_clag2z;
     void *LAPACKE_clag2z_work;
-    void *LAPACKE_clangb;
-    void *LAPACKE_clangb_work;
     void *LAPACKE_clange;
     void *LAPACKE_clange_work;
     void *LAPACKE_clanhe;
@@ -603,7 +601,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ctrsna;
     void *LAPACKE_ctrsna_work;
     void *LAPACKE_ctrsyl;
-    void *LAPACKE_ctrsyl3_work;
     void *LAPACKE_ctrsyl_work;
     void *LAPACKE_ctrtri;
     void *LAPACKE_ctrtri_work;
@@ -843,8 +840,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dlag2s_work;
     void *LAPACKE_dlamch;
     void *LAPACKE_dlamch_work;
-    void *LAPACKE_dlangb;
-    void *LAPACKE_dlangb_work;
     void *LAPACKE_dlange;
     void *LAPACKE_dlange_work;
     void *LAPACKE_dlansy;
@@ -1222,8 +1217,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dtrsna;
     void *LAPACKE_dtrsna_work;
     void *LAPACKE_dtrsyl;
-    void *LAPACKE_dtrsyl3;
-    void *LAPACKE_dtrsyl3_work;
     void *LAPACKE_dtrsyl_work;
     void *LAPACKE_dtrtri;
     void *LAPACKE_dtrtri_work;
@@ -1424,8 +1417,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_slag2d_work;
     void *LAPACKE_slamch;
     void *LAPACKE_slamch_work;
-    void *LAPACKE_slangb;
-    void *LAPACKE_slangb_work;
     void *LAPACKE_slange;
     void *LAPACKE_slange_work;
     void *LAPACKE_slansy;
@@ -1799,8 +1790,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_strsna;
     void *LAPACKE_strsna_work;
     void *LAPACKE_strsyl;
-    void *LAPACKE_strsyl3;
-    void *LAPACKE_strsyl3_work;
     void *LAPACKE_strsyl_work;
     void *LAPACKE_strtri;
     void *LAPACKE_strtri_work;
@@ -2132,8 +2121,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zlacrm_work;
     void *LAPACKE_zlag2c;
     void *LAPACKE_zlag2c_work;
-    void *LAPACKE_zlangb;
-    void *LAPACKE_zlangb_work;
     void *LAPACKE_zlange;
     void *LAPACKE_zlange_work;
     void *LAPACKE_zlanhe;
@@ -2381,8 +2368,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ztrsna;
     void *LAPACKE_ztrsna_work;
     void *LAPACKE_ztrsyl;
-    void *LAPACKE_ztrsyl3;
-    void *LAPACKE_ztrsyl3_work;
     void *LAPACKE_ztrsyl_work;
     void *LAPACKE_ztrtri;
     void *LAPACKE_ztrtri_work;
