@@ -31,7 +31,7 @@
 *>
 *> \verbatim
 *>
-*> CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS(3)
+*> CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS
 *> \endverbatim
 *
 *  Arguments:
@@ -184,7 +184,7 @@
       INTEGER            NTYPE1, NTYPES
       PARAMETER          ( NTYPE1 = 10, NTYPES = 18 )
       INTEGER            NTESTS
-      PARAMETER          ( NTESTS = 10 )
+      PARAMETER          ( NTESTS = 9 )
       INTEGER            NTRAN
       PARAMETER          ( NTRAN = 3 )
       REAL               ONE, ZERO
@@ -195,13 +195,13 @@
       CHARACTER*3        PATH
       INTEGER            I, IDIAG, IMAT, IN, INB, INFO, IRHS, ITRAN,
      $                   IUPLO, K, LDA, N, NB, NERRS, NFAIL, NRHS, NRUN
-      REAL               AINVNM, ANORM, BIGNUM, DUMMY, RCOND, RCONDC,
-     $                   RCONDI, RCONDO, RES, SCALE, SLAMCH
+      REAL               AINVNM, ANORM, DUMMY, RCOND, RCONDC, RCONDI,
+     $                   RCONDO, SCALE
 *     ..
 *     .. Local Arrays ..
       CHARACTER          TRANSS( NTRAN ), UPLOS( 2 )
       INTEGER            ISEED( 4 ), ISEEDY( 4 )
-      REAL               RESULT( NTESTS ), SCALE3( 2 )
+      REAL               RESULT( NTESTS )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -210,9 +210,9 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASUM, CCOPY, CERRTR, CGET04,
-     $                   CLACPY, CLARHS, CLATRS, CLATRS3, CLATTR,
-     $                   CSSCAL, CTRCON, CTRRFS, CTRT01, CTRT02, CTRT03,
-     $                   CTRT05, CTRT06, CTRTRI, CTRTRS, XLAENV, SLAMCH
+     $                   CLACPY, CLARHS, CLATRS, CLATTR, CTRCON, CTRRFS,
+     $                   CTRT01, CTRT02, CTRT03, CTRT05, CTRT06, CTRTRI,
+     $                   CTRTRS, XLAENV
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
@@ -236,7 +236,6 @@
 *
       PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'TR'
-      BIGNUM = SLAMCH('Overflow') / SLAMCH('Precision')
       NRUN = 0
       NFAIL = 0
       NERRS = 0
@@ -381,7 +380,7 @@
 *                       This line is needed on a Sun SPARCstation.
 *
                         IF( N.GT.0 )
-     $                     DUMMY = REAL( A( 1 ) )
+     $                     DUMMY = A( 1 )
 *
                         CALL CTRT02( UPLO, TRANS, DIAG, N, NRHS, A, LDA,
      $                               X, LDA, B, LDA, WORK, RWORK,
@@ -536,32 +535,6 @@
      $                         RWORK, ONE, B( N+1 ), LDA, X, LDA, WORK,
      $                         RESULT( 9 ) )
 *
-*+    TEST 10
-*                 Solve op(A)*X = B.
-*
-                  SRNAMT = 'CLATRS3'
-                  CALL CCOPY( N, X, 1, B, 1 )
-                  CALL CCOPY( N, X, 1, B, 1 )
-                  CALL CSCAL( N, BIGNUM, B( N+1 ), 1 )
-                  CALL CLATRS3( UPLO, TRANS, DIAG, 'N', N, 2, A, LDA,
-     $                          B, MAX(1, N), SCALE3, RWORK, WORK, NMAX,
-     $                          INFO )
-*
-*                 Check error code from CLATRS3.
-*
-                  IF( INFO.NE.0 )
-     $               CALL ALAERH( PATH, 'CLATRS3', INFO, 0,
-     $                            UPLO // TRANS // DIAG // 'Y', N, N,
-     $                            -1, -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  CALL CTRT03( UPLO, TRANS, DIAG, N, 1, A, LDA,
-     $                         SCALE3( 1 ), RWORK, ONE, B( 1 ), LDA,
-     $                         X, LDA, WORK, RESULT( 10 ) )
-                  CALL CSSCAL( N, BIGNUM, X, 1 )
-                  CALL CTRT03( UPLO, TRANS, DIAG, N, 1, A, LDA,
-     $                         SCALE3( 2 ), RWORK, ONE, B( N+1 ), LDA,
-     $                         X, LDA, WORK, RESULT( 10 ) )
-                  RESULT( 10 ) = MAX( RESULT( 10 ), RES )
-*
 *                 Print information about the tests that did not pass
 *                 the threshold.
 *
@@ -579,14 +552,7 @@
      $                  DIAG, 'Y', N, IMAT, 9, RESULT( 9 )
                      NFAIL = NFAIL + 1
                   END IF
-                  IF( RESULT( 10 ).GE.THRESH ) THEN
-                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                  CALL ALAHD( NOUT, PATH )
-                     WRITE( NOUT, FMT = 9996 )'CLATRS3', UPLO, TRANS,
-     $                  DIAG, 'N', N, IMAT, 10, RESULT( 10 )
-                     NFAIL = NFAIL + 1
-                  END IF
-                  NRUN = NRUN + 3
+                  NRUN = NRUN + 2
    90          CONTINUE
   100       CONTINUE
   110    CONTINUE
