@@ -316,20 +316,6 @@
 *>           Not referenced if PIVTNG = 'N'. Not modified.
 *> \endverbatim
 *>
-*> \param[in] SPARSE
-*> \verbatim
-*>          SPARSE is DOUBLE PRECISION
-*>           On entry specifies the sparsity of the matrix if a sparse
-*>           matrix is to be generated. SPARSE should lie between
-*>           0 and 1. To generate a sparse matrix, for each matrix entry
-*>           a uniform ( 0, 1 ) random number x is generated and
-*>           compared to SPARSE; if x is larger the matrix entry
-*>           is unchanged and if x is smaller the entry is set
-*>           to zero. Thus on the average a fraction SPARSE of the
-*>           entries will be set to zero.
-*>           Not modified.
-*> \endverbatim
-*>
 *> \param[in] KL
 *> \verbatim
 *>          KL is INTEGER
@@ -350,6 +336,20 @@
 *>           Not modified.
 *> \endverbatim
 *>
+*> \param[in] SPARSE
+*> \verbatim
+*>          SPARSE is DOUBLE PRECISION
+*>           On entry specifies the sparsity of the matrix if a sparse
+*>           matrix is to be generated. SPARSE should lie between
+*>           0 and 1. To generate a sparse matrix, for each matrix entry
+*>           a uniform ( 0, 1 ) random number x is generated and
+*>           compared to SPARSE; if x is larger the matrix entry
+*>           is unchanged and if x is smaller the entry is set
+*>           to zero. Thus on the average a fraction SPARSE of the
+*>           entries will be set to zero.
+*>           Not modified.
+*> \endverbatim
+*>
 *> \param[in] ANORM
 *> \verbatim
 *>          ANORM is DOUBLE PRECISION
@@ -416,7 +416,7 @@
 *>           If PACK='C' or 'R', LDA must be at least 1.
 *>           If PACK='B', or 'Q', LDA must be MIN ( KU+1, N )
 *>           If PACK='Z', LDA must be at least KUU+KLL+1, where
-*>           KUU = MIN ( KU, N-1 ) and KLL = MIN ( KL, N-1 )
+*>           KUU = MIN ( KU, N-1 ) and KLL = MIN ( KL, M-1 )
 *>           Not modified.
 *> \endverbatim
 *>
@@ -480,8 +480,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
 *> \ingroup complex16_matgen
 *
 *  =====================================================================
@@ -490,10 +488,9 @@
      $                   CONDR, PIVTNG, IPIVOT, KL, KU, SPARSE, ANORM,
      $                   PACK, A, LDA, IWORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIST, GRADE, PACK, PIVTNG, RSIGN, SYM
@@ -531,9 +528,11 @@
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
-      DOUBLE PRECISION   ZLANGB, ZLANGE, ZLANSB, ZLANSP, ZLANSY
+      DOUBLE PRECISION   ZLANGB, ZLANGE, ZLANSB,
+     $                   ZLANSP, ZLANSY
       COMPLEX*16         ZLATM2, ZLATM3
-      EXTERNAL           LSAME, ZLANGB, ZLANGE, ZLANSB, ZLANSP, ZLANSY,
+      EXTERNAL           LSAME, ZLANGB, ZLANGE,
+     $                   ZLANSB, ZLANSP, ZLANSY,
      $                   ZLATM2, ZLATM3
 *     ..
 *     .. External Subroutines ..
@@ -900,7 +899,8 @@
 *
             DO 170 J = 1, N
                DO 160 I = 1, J
-                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -919,7 +919,8 @@
 *
             DO 190 J = 1, N
                DO 180 I = 1, J
-                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -938,7 +939,8 @@
 *
             DO 210 J = 1, N
                DO 200 I = 1, J
-                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
 *
@@ -966,7 +968,8 @@
 *
             DO 230 J = 1, N
                DO 220 I = 1, J
-                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
 *
@@ -1019,7 +1022,8 @@
 *
             DO 270 J = 1, N
                DO 260 I = J - KUU, J
-                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = ZLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -1109,7 +1113,8 @@
 *
             DO 390 J = 1, N
                DO 380 I = 1, J
-                  A( I, J ) = ZLATM2( M, N, I, J, KL, KU, IDIST, ISEED,
+                  A( I, J ) = ZLATM2( M, N, I, J, KL, KU, IDIST,
+     $                        ISEED,
      $                        D, IGRADE, DL, DR, IPVTNG, IWORK, SPARSE )
                   IF( I.NE.J )
      $               A( J, I ) = CZERO
@@ -1145,7 +1150,8 @@
                      ISUB = 1
                      JSUB = JSUB + 1
                   END IF
-                  A( ISUB, JSUB ) = ZLATM2( M, N, I, J, KL, KU, IDIST,
+                  A( ISUB, JSUB ) = ZLATM2( M, N, I, J, KL, KU,
+     $                              IDIST,
      $                              ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                              IWORK, SPARSE )
   420          CONTINUE
@@ -1203,7 +1209,8 @@
                      A( J-I+1, I+N ) = CZERO
                   ELSE
                      IF( ISYM.EQ.0 ) THEN
-                        A( J-I+1, I ) = DCONJG( ZLATM2( M, N, I, J, KL,
+                        A( J-I+1, I ) = DCONJG( ZLATM2( M, N, I, J,
+     $                                  KL,
      $                                  KU, IDIST, ISEED, D, IGRADE, DL,
      $                                  DR, IPVTNG, IWORK, SPARSE ) )
                      ELSE
@@ -1219,7 +1226,8 @@
 *
             DO 510 J = 1, N
                DO 500 I = J - KUU, J
-                  A( I-J+KUU+1, J ) = ZLATM2( M, N, I, J, KL, KU, IDIST,
+                  A( I-J+KUU+1, J ) = ZLATM2( M, N, I, J, KL, KU,
+     $                                IDIST,
      $                                ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                                IWORK, SPARSE )
   500          CONTINUE
