@@ -125,7 +125,6 @@
 *>          RESULT is DOUBLE PRECISION array, dimension (2)
 *>          RESULT(1) = | A E  -  E W | / ( |A| |E| ulp )
 *>          RESULT(2) = max | m-norm(E(j)) - 1 | / ( n ulp )
-*>                       j
 *> \endverbatim
 *
 *  Authors:
@@ -136,15 +135,18 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
+*> \date December 2016
+*
 *> \ingroup complex16_eig
 *
 *  =====================================================================
       SUBROUTINE ZGET22( TRANSA, TRANSE, TRANSW, N, A, LDA, E, LDE, W,
      $                   WORK, RWORK, RESULT )
 *
-*  -- LAPACK test routine --
+*  -- LAPACK test routine (version 3.7.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANSA, TRANSE, TRANSW
@@ -297,7 +299,7 @@
          RESULT( 1 ) = ( ERRNRM / ANORM ) / ULP
       ELSE
          IF( ANORM.LT.ONE ) THEN
-            RESULT( 1 ) = ONE / ULP
+            RESULT( 1 ) = ( MIN( ERRNRM, ANORM ) / ANORM ) / ULP
          ELSE
             RESULT( 1 ) = MIN( ERRNRM / ANORM, ONE ) / ULP
          END IF
