@@ -492,6 +492,8 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
+*> \date June 2016
+*
 *> \ingroup complex16_eig
 *
 *  =====================================================================
@@ -501,9 +503,10 @@
      $                   ALPHA3, BETA3, EVECTL, EVECTR, WORK, LWORK,
      $                   RWORK, LLWORK, RESULT, INFO )
 *
-*  -- LAPACK test routine --
+*  -- LAPACK test routine (version 3.7.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     June 2016
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTDIF
@@ -559,9 +562,9 @@
       EXTERNAL           DLAMCH, ZLANGE, ZLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLASUM, XERBLA, ZGEQR2, ZGET51, ZGET52, ZGGHRD,
-     $                   ZHGEQZ, ZLACPY, ZLARFG, ZLASET, ZLATM4, ZTGEVC,
-     $                   ZUNM2R
+      EXTERNAL           DLABAD, DLASUM, XERBLA, ZGEQR2, ZGET51, ZGET52,
+     $                   ZGGHRD, ZHGEQZ, ZLACPY, ZLARFG, ZLASET, ZLATM4,
+     $                   ZTGEVC, ZUNM2R
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, DCONJG, MAX, MIN, SIGN
@@ -639,6 +642,7 @@
       ULP = DLAMCH( 'Epsilon' )*DLAMCH( 'Base' )
       SAFMIN = SAFMIN / ULP
       SAFMAX = ONE / SAFMIN
+      CALL DLABAD( SAFMIN, SAFMAX )
       ULPINV = ONE / ULP
 *
 *     The values RMAGN(2:3) depend on N, see below.
